% Auto-generated chapter 5 for abudawud
% Hadiths in this chapter: 121

\hadithdefcmd{abudawud}{1250}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا ابْنُ عُلَيَّةَ، حَدَّثَنَا دَاوُدُ بْنُ أَبِي هِنْدٍ، حَدَّثَنِي النُّعْمَانُ بْنُ سَالِمٍ، عَنْ عَمْرِو بْنِ أَوْسٍ، عَنْ عَنْبَسَةَ بْنِ أَبِي سُفْيَانَ، عَنْ أُمِّ حَبِيبَةَ، قَالَتْ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ صَلَّى فِي يَوْمٍ ثِنْتَىْ عَشْرَةَ رَكْعَةً تَطَوُّعًا بُنِيَ لَهُ بِهِنَّ بَيْتٌ فِي الْجَنَّةِ ‏"‏ ‏.‏\hadithno{1250}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (728)}\hadithtrans{Narrated Umm Habibah:The Prophet (ﷺ) as saying: If anyone prays in a day and a night twelve rak'ahs voluntarily (supererogatory prayer), a house will be built from him in Paradise on account of these (rak'ahs)}}
\hadithdefcmd{abudawud}{1251}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا خَالِدٌ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا خَالِدٌ، - الْمَعْنَى - عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، قَالَ سَأَلْتُ عَائِشَةَ عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ التَّطَوُّعِ فَقَالَتْ كَانَ يُصَلِّي قَبْلَ الظُّهْرِ أَرْبَعًا فِي بَيْتِي ثُمَّ يَخْرُجُ فَيُصَلِّي بِالنَّاسِ ثُمَّ يَرْجِعُ إِلَى بَيْتِي فَيُصَلِّي رَكْعَتَيْنِ وَكَانَ يُصَلِّي بِالنَّاسِ الْمَغْرِبَ ثُمَّ يَرْجِعُ إِلَى بَيْتِي فَيُصَلِّي رَكْعَتَيْنِ وَكَانَ يُصَلِّي بِهِمُ الْعِشَاءَ ثُمَّ يَدْخُلُ بَيْتِي فَيُصَلِّي رَكْعَتَيْنِ وَكَانَ يُصَلِّي مِنَ اللَّيْلِ تِسْعَ رَكَعَاتٍ فِيهِنَّ الْوِتْرُ وَكَانَ يُصَلِّي لَيْلاً طَوِيلاً قَائِمًا وَلَيْلاً طَوِيلاً جَالِسًا فَإِذَا قَرَأَ وَهُوَ قَائِمٌ رَكَعَ وَسَجَدَ وَهُوَ قَائِمٌ وَإِذَا قَرَأَ وَهُوَ قَاعِدٌ رَكَعَ وَسَجَدَ وَهُوَ قَاعِدٌ وَكَانَ إِذَا طَلَعَ الْفَجْرُ صَلَّى رَكْعَتَيْنِ ثُمَّ يَخْرُجُ فَيُصَلِّي بِالنَّاسِ صَلاَةَ الْفَجْرِ صلى الله عليه وسلم ‏.‏\hadithno{1251}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (730)}\hadithtrans{Narrated Abd Allah b. Shaqiq:I asked A'ishah about the voluntary prayers offered by the Messenger of Allah (ﷺ). She replied: Before the noon prayer he would pray four rak'ahs in my house, then go out and lead the people in prayer, then return to my house and pray two rak'ahs. He would lead the people in the sunset prayer, then return to my house and pray two rak'ahs. Then he would lead the people in the night prayer, and enter my house and pray two rak'ahs. He would pray nine rak'ahs during the night, including witr (prayer). At night he would pray for a long time standing and for a long time sitting. When he recited the Qur'an while standing, he would bow and prostrate himself from the standing position, and when he recited while sitting, he would bow and prostrate himself from the sitting position, and when dawn came he prayed two rak'ahs, then he would come out and lead the people in the dawn prayer}}
\hadithdefcmd{abudawud}{1252}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي قَبْلَ الظُّهْرِ رَكْعَتَيْنِ وَبَعْدَهَا رَكْعَتَيْنِ - وَبَعْدَ الْمَغْرِبِ رَكْعَتَيْنِ - فِي بَيْتِهِ وَبَعْدَ صَلاَةِ الْعِشَاءِ رَكْعَتَيْنِ وَكَانَ لاَ يُصَلِّي بَعْدَ الْجُمُعَةِ حَتَّى يَنْصَرِفَ فَيُصَلِّي رَكْعَتَيْنِ ‏.‏\hadithno{1252}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (937) Sahih Muslim (882)}\hadithtrans{Narrated Abd Allah b. 'Umar:The Messenger of Allah (ﷺ) would pray two rak'ahs before and two after the noon prayer, two after the sunset prayer in his house, and two after the night prayer. He would not pray after the Friday prayer till he departed. He would then pray two rak'ahs}}
\hadithdefcmd{abudawud}{1253}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ الْمُنْتَشِرِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ لاَ يَدَعُ أَرْبَعًا قَبْلَ الظُّهْرِ وَرَكْعَتَيْنِ قَبْلَ صَلاَةِ الْغَدَاةِ ‏.‏\hadithno{1253}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1182)}\hadithtrans{Narrated 'Aishah:The Prophet (ﷺ) never omitted four rak'ahs before the noon prayer, and two rak'ahs before the dawn prayer}}
\hadithdefcmd{abudawud}{1254}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، حَدَّثَنِي عَطَاءٌ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَكُنْ عَلَى شَىْءٍ مِنَ النَّوَافِلِ أَشَدَّ مُعَاهَدَةً مِنْهُ عَلَى الرَّكْعَتَيْنِ قَبْلَ الصُّبْحِ ‏.‏\hadithno{1254}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1169) Sahih Muslim (724)}\hadithtrans{Narrated 'Aishah:The Messenger of Allah (ﷺ) was more particular about observing the supererogatory rak'ahs before the dawn prayer than about observing any of the other supererogatory prayers}}
\hadithdefcmd{abudawud}{1255}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي شُعَيْبٍ الْحَرَّانِيُّ، حَدَّثَنَا زُهَيْرُ بْنُ مُعَاوِيَةَ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُخَفِّفُ الرَّكْعَتَيْنِ قَبْلَ صَلاَةِ الْفَجْرِ حَتَّى إِنِّي لأَقُولُ هَلْ قَرَأَ فِيهِمَا بِأُمِّ الْقُرْآنِ\hadithno{1255}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1171) Sahih Muslim (724)}\hadithtrans{Narrated 'Aishah:The Prophet (ﷺ) would pray two rak'ahs before the dawn prayer lightly so much so that I would say: Did he recite Surah al-Fatihah in them}}
\hadithdefcmd{abudawud}{1256}{حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، حَدَّثَنَا يَزِيدُ بْنُ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَرَأَ فِي رَكْعَتَىِ الْفَجْرِ ‏\{‏ قُلْ يَا أَيُّهَا الْكَافِرُونَ ‏\}‏ وَ ‏\{‏ قُلْ هُوَ اللَّهُ أَحَدٌ ‏\}‏ ‏.‏\hadithno{1256}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (726)}\hadithtrans{Narrated Abu Hurairah:The Prophet (ﷺ) would recite in the two (supererogatory) rak'ahs of the dawn prayer: "Say, O unbelievers" [Surat al-Kafiroon:1] and "Say: He is Allah, the one" [Surat al-Ikhlas:]}}
\hadithdefcmd{abudawud}{1257}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا أَبُو الْمُغِيرَةِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْعَلاَءِ، حَدَّثَنِي أَبُو زِيَادَةَ، عُبَيْدُ اللَّهِ بْنُ زِيَادٍ الْكِنْدِيُّ عَنْ بِلاَلٍ، أَنَّهُ حَدَّثَهُ أَنَّهُ، أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم لِيُؤْذِنَهُ بِصَلاَةِ الْغَدَاةِ فَشَغَلَتْ عَائِشَةُ - رضى الله عنها - بِلاَلاً بِأَمْرٍ سَأَلَتْهُ عَنْهُ حَتَّى فَضَحَهُ الصُّبْحُ فَأَصْبَحَ جِدًّا قَالَ فَقَامَ بِلاَلٌ فَآذَنَهُ بِالصَّلاَةِ وَتَابَعَ أَذَانَهُ فَلَمْ يَخْرُجْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمَّا خَرَجَ صَلَّى بِالنَّاسِ وَأَخْبَرَهُ أَنَّ عَائِشَةَ شَغَلَتْهُ بِأَمْرٍ سَأَلَتْهُ عَنْهُ حَتَّى أَصْبَحَ جِدًّا وَأَنَّهُ أَبْطَأَ عَلَيْهِ بِالْخُرُوجِ فَقَالَ ‏"‏ إِنِّي كُنْتُ رَكَعْتُ رَكْعَتَىِ الْفَجْرِ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّكَ أَصْبَحْتَ جِدًّا ‏.‏ قَالَ ‏"‏ لَوْ أَصْبَحْتُ أَكْثَرَ مِمَّا أَصْبَحْتُ لَرَكَعْتُهُمَا وَأَحْسَنْتُهُمَا وَأَجْمَلْتُهُمَا ‏"‏ ‏.‏\hadithno{1257}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Bilal: Ziyadah al-Kindi reported on the authority of Bilal that he (Bilal) came to the Messenger of Allah (ﷺ) to inform him about the dawn prayer. Aisha kept Bilal engaged in a matter which she asked him till the day was bright and it became fairly light. Bilal then stood up and called him to prayer and called him repeatedly. The Messenger of Allah (ﷺ) did not yet come out. When he came out, he led the people in prayer and he (Bilal) informed him that Aisha had kept him engaged in a matter which she asked him till it became fairly light; hence he became late in reaching him (in time). He (Bilal) said: Messenger of Allah, the dawn became fairly bright. He said: If the dawn became brighter than it is now, I would pray them (the two rak'ahs of the sunnah prayer), offer them well and in a more beautiful manner}}
\hadithdefcmd{abudawud}{1258}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا خَالِدٌ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، - يَعْنِي ابْنَ إِسْحَاقَ الْمَدَنِيَّ - عَنِ ابْنِ زَيْدٍ، عَنِ ابْنِ سِيْلاَنَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَدَعُوهُمَا وَإِنْ طَرَدَتْكُمُ الْخَيْلُ ‏"‏ ‏.‏\hadithno{1258}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: Do not omit them (the two rak'ahs before the dawn prayer) even if you are driven away by the horses}}
\hadithdefcmd{abudawud}{1259}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا عُثْمَانُ بْنُ حَكِيمٍ، أَخْبَرَنِي سَعِيدُ بْنُ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ كَثِيرًا، مِمَّا كَانَ يَقْرَأُ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي رَكْعَتَىِ الْفَجْرِ بِـ ‏\{‏ آمَنَّا بِاللَّهِ وَمَا أُنْزِلَ إِلَيْنَا ‏\}‏ هَذِهِ الآيَةَ قَالَ هَذِهِ فِي الرَّكْعَةِ الأُولَى وَفِي الرَّكْعَةِ الآخِرَةِ بِـ ‏\{‏ آمَنَّا بِاللَّهِ وَاشْهَدْ بِأَنَّا مُسْلِمُونَ ‏\}‏ ‏.‏\hadithno{1259}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (727)}\hadithtrans{Narrated 'Abd Allah b. 'Abbas:The Messenger of Allah (ﷺ) used to recite in both rak'ahs of the dawn prayer: "Say: We believe in Allah and in the revelation given to us" (3:84) . This is in the first rak'ah and in the second rak'ah (he recited): "We believe in Allah and bear witness that we submit ourself (to Him)." (3:)}}
\hadithdefcmd{abudawud}{1260}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ بْنِ سُفْيَانَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنِ مُحَمَّدٍ، عَنْ عُثْمَانَ بْنِ عُمَرَ، - يَعْنِي ابْنَ مُوسَى - عَنْ أَبِي الْغَيْثِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ فِي رَكْعَتَىِ الْفَجْرِ ‏\{‏ قُلْ آمَنَّا بِاللَّهِ وَمَا أُنْزِلَ عَلَيْنَا ‏\}‏ فِي الرَّكْعَةِ الأُولَى وَفِي الرَّكْعَةِ الأُخْرَى بِهَذِهِ الآيَةِ ‏\{‏ رَبَّنَا آمَنَّا بِمَا أَنْزَلْتَ وَاتَّبَعْنَا الرَّسُولَ فَاكْتُبْنَا مَعَ الشَّاهِدِينَ ‏\}‏ أَوْ ‏\{‏ إِنَّا أَرْسَلْنَاكَ بِالْحَقِّ بَشِيرًا وَنَذِيرًا وَلاَ تُسْأَلُ عَنْ أَصْحَابِ الْجَحِيمِ ‏\}‏ شَكَّ الدَّرَاوَرْدِيُّ ‏.‏\hadithno{1260}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah:That he heard the Prophet (ﷺ) recite in both rak'ahs of the dawn: "Say: We believe in Allah, and in the revelation given to us" (3:84). This is in the first rak'ah. In the second rak'ah he recited this verse: "Our Lord, we have believed in what You have sent down, and we follow the Messenger, so write us down among those who bear witness." or he recited: "Surely, we have sent you with the truth as a bringer of glad tidings, and a warner. And you will not be asked about the inhabitants of the Blazing Fire" (2:119). Al-Darawardi doubted (which of the verse he recited)}}
\hadithdefcmd{abudawud}{1261}{حَدَّثَنَا مُسَدَّدٌ، وَأَبُو كَامِلٍ وَعُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ قَالُوا حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا صَلَّى أَحَدُكُمُ الرَّكْعَتَيْنِ قَبْلَ الصُّبْحِ فَلْيَضْطَجِعْ عَلَى يَمِينِهِ ‏"‏ ‏.‏ فَقَالَ لَهُ مَرْوَانُ بْنُ الْحَكَمِ أَمَا يُجْزِئُ أَحَدَنَا مَمْشَاهُ إِلَى الْمَسْجِدِ حَتَّى يَضْطَجِعَ عَلَى يَمِينِهِ قَالَ عُبَيْدُ اللَّهِ فِي حَدِيثِهِ قَالَ لاَ ‏.‏ قَالَ فَبَلَغَ ذَلِكَ ابْنَ عُمَرَ فَقَالَ أَكْثَرَ أَبُو هُرَيْرَةَ عَلَى نَفْسِهِ ‏.‏ قَالَ فَقِيلَ لاِبْنِ عُمَرَ هَلْ تُنْكِرُ شَيْئًا مِمَّا يَقُولُ قَالَ لاَ وَلَكِنَّهُ اجْتَرَأَ وَجَبُنَّا ‏.‏ قَالَ فَبَلَغَ ذَلِكَ أَبَا هُرَيْرَةَ قَالَ فَمَا ذَنْبِي إِنْ كُنْتُ حَفِظْتُ وَنَسُوا ‏.‏\hadithno{1261}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: If any of you prays two rak'ahs before the dawn prayer, he should lie at his right side. Marwan ibn al-Hakam said to him: Is it not enough that one of us walks to the mosque until he lies at his right side? According to the version of Ubaydullah, he (AbuHurayrah) replied: No. This statement (of AbuHurayrah) reached Ibn Umar. He said: AbuHurayrah exceed limits on himself. He was asked: Do you look askance at what he says? He replied: No, but he dared and we showed cowardice. This (criticism of Ibn Umar) reached AbuHurayrah. He said: What is my sin if I remembered and they forgot?}}
\hadithdefcmd{abudawud}{1262}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا بِشْرُ بْنُ عُمَرَ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ سَالِمٍ أَبِي النَّضْرِ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَضَى صَلاَتَهُ مِنْ آخِرِ اللَّيْلِ نَظَرَ فَإِنْ كُنْتُ مُسْتَيْقِظَةً حَدَّثَنِي وَإِنْ كُنْتُ نَائِمَةً أَيْقَظَنِي وَصَلَّى الرَّكْعَتَيْنِ ثُمَّ اضْطَجَعَ حَتَّى يَأْتِيَهُ الْمُؤَذِّنُ فَيُؤْذِنَهُ بِصَلاَةِ الصُّبْحِ فَيُصَلِّي رَكْعَتَيْنِ خَفِيفَتَيْنِ ثُمَّ يَخْرُجُ إِلَى الصَّلاَةِ ‏.‏\hadithno{1262}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1119) Sahih Muslim (743)}\hadithtrans{Narrated 'Aishah:When the Messenger of Allah (ﷺ) finished his prayer late in the night, he would see. If I was awake, he would talk to me. If I was sleeping, he would awaken me, and pray two rak'ahs, then he would lie down as long as the mu'adhdhin came to him and call him for the dawn prayer. Then he would pray two rak'ahs lightly and come out for prayer}}
\hadithdefcmd{abudawud}{1263}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنْ زِيَادِ بْنِ سَعْدٍ، عَمَّنْ حَدَّثَهُ - ابْنِ أَبِي عَتَّابٍ، أَوْ غَيْرِهِ - عَنْ أَبِي سَلَمَةَ، قَالَ قَالَتْ عَائِشَةُ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا صَلَّى رَكْعَتَىِ الْفَجْرِ فَإِنْ كُنْتُ نَائِمَةً اضْطَجَعَ وَإِنْ كُنْتُ مُسْتَيْقِظَةً حَدَّثَنِي ‏.‏\hadithno{1263}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: When the Prophet (ﷺ) prayed the two rak'ahs of the dawn prayer, he would lie down if I was asleep; in case I was awake, he would talk to me}}
\hadithdefcmd{abudawud}{1264}{حَدَّثَنَا عَبَّاسٌ الْعَنْبَرِيُّ، وَزِيَادُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا سَهْلُ بْنُ حَمَّادٍ، عَنْ أَبِي مَكِينٍ، حَدَّثَنَا أَبُو الْفَضْلِ، - رَجُلٌ مِنَ الأَنْصَارِ - عَنْ مُسْلِمِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، قَالَ خَرَجْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم لِصَلاَةِ الصُّبْحِ فَكَانَ لاَ يَمُرُّ بِرَجُلٍ إِلاَّ نَادَاهُ بِالصَّلاَةِ أَوْ حَرَّكَهُ بِرِجْلِهِ ‏.‏ قَالَ زِيَادٌ قَالَ حَدَّثَنَا أَبُو الْفُضَيْلِ ‏.‏\hadithno{1264}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuBakrah: I came out with the Prophet (ﷺ) to offer the dawn prayer. When he passed by a sleeping man he called him for prayer or moved him with his foot. The narrator Ziyad said: This tradition has been reported to us by AbulFadl}}
\hadithdefcmd{abudawud}{1265}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَاصِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ سَرْجِسَ، قَالَ جَاءَ رَجُلٌ وَالنَّبِيُّ صلى الله عليه وسلم يُصَلِّي الصُّبْحَ فَصَلَّى الرَّكْعَتَيْنِ ثُمَّ دَخَلَ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي الصَّلاَةِ فَلَمَّا انْصَرَفَ قَالَ ‏ "‏ يَا فُلاَنُ أَيَّتُهُمَا صَلاَتُكَ الَّتِي صَلَّيْتَ وَحْدَكَ أَوِ الَّتِي صَلَّيْتَ مَعَنَا ‏"‏ ‏.‏\hadithno{1265}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (712)}\hadithtrans{Narrated 'Abd Allah b. Sarjas:A man came while the Prophet (ﷺ) was leading the people in the dawn prayer. He prayed the two rak'ahs and then joined the congregational prayer led by the Prophet (ﷺ). When he finished the prayer, the Prophet (ﷺ) said: So-and-so, which was your real prayer, the one you prayed alone or the one offered with us ?}}
\hadithdefcmd{abudawud}{1266}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ وَرْقَاءَ، ح وَحَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، ح وَحَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ حَمَّادِ بْنِ زَيْدٍ، عَنْ أَيُّوبَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُتَوَكِّلِ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا زَكَرِيَّا بْنُ إِسْحَاقَ، كُلُّهُمْ عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أُقِيمَتِ الصَّلاَةُ فَلاَ صَلاَةَ إِلاَّ الْمَكْتُوبَةُ ‏"‏ ‏.‏\hadithno{1266}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (710)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ)as saying: When the iqamah is pronounced for prayer, no prayer is valid except the obligatory prayer}}
\hadithdefcmd{abudawud}{1267}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ نُمَيْرٍ، عَنْ سَعْدِ بْنِ سَعِيدٍ، حَدَّثَنِي مُحَمَّدُ بْنُ إِبْرَاهِيمَ، عَنْ قَيْسِ بْنِ عَمْرٍو، قَالَ رَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً يُصَلِّي بَعْدَ صَلاَةِ الصُّبْحِ رَكْعَتَيْنِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صَلاَةُ الصُّبْحِ رَكْعَتَانِ ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ إِنِّي لَمْ أَكُنْ صَلَّيْتُ الرَّكْعَتَيْنِ اللَّتَيْنِ قَبْلَهُمَا فَصَلَّيْتُهُمَا الآنَ ‏.‏ فَسَكَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1267}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Qays ibn Amr: The Messenger of Allah (ﷺ) saw a person praying after the congregational prayer at dawn was over. The Messenger of Allah (ﷺ) said: There are two rak'ahs of the dawn prayer (i.e. the prescribed rak'ahs). The man replied: I did not pray the two rak'ahs before the dawn prayer. Hence I offered them now. The Messenger of Allah (ﷺ) kept silent}}
\hadithdefcmd{abudawud}{1268}{حَدَّثَنَا حَامِدُ بْنُ يَحْيَى الْبَلْخِيُّ، قَالَ قَالَ سُفْيَانُ كَانَ عَطَاءُ بْنُ أَبِي رَبَاحٍ يُحَدِّثُ بِهَذَا الْحَدِيثِ عَنْ سَعْدِ بْنِ سَعِيدٍ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَى عَبْدُ رَبِّهِ وَيَحْيَى ابْنَا سَعِيدٍ هَذَا الْحَدِيثَ مُرْسَلاً أَنَّ جَدَّهُمْ زَيْدًا صَلَّى مَعَ النَّبِيِّ صلى الله عليه وسلم بِهَذِهِ الْقِصَّةِ ‏.‏\hadithno{1268}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{This tradition has also been transmitted by 'Ata b. Abi Rabah on the authority of Sa'd b. Sa'id through a different chain of narrators. Abu Dawud said:'Abd Rabbihi and Yahya b. Sa'id also narrated this tradition from the Prophet (ﷺ) omitting the name of the Companion (mursal). Their grandfather Zaid prayed along with the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{1269}{حَدَّثَنَا مُؤَمَّلُ بْنُ الْفَضْلِ، حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبٍ، عَنِ النُّعْمَانِ، عَنْ مَكْحُولٍ، عَنْ عَنْبَسَةَ بْنِ أَبِي سُفْيَانَ، قَالَ قَالَتْ أُمُّ حَبِيبَةَ زَوْجُ النَّبِيِّ صلى الله عليه وسلم قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَافَظَ عَلَى أَرْبَعِ رَكَعَاتٍ قَبْلَ الظُّهْرِ وَأَرْبَعٍ بَعْدَهَا حَرُمَ عَلَى النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ الْعَلاَءُ بْنُ الْحَارِثِ وَسُلَيْمَانُ بْنُ مُوسَى عَنْ مَكْحُولٍ بِإِسْنَادِهِ مِثْلَهُ ‏.‏\hadithno{1269}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Umm Habibah: The Prophet (ﷺ) said: If anyone keeps on praying regularly four rak'ahs before and four after the noon prayer, he will not enter the Hell-fire. Abu Dawud said: Al-'Ala' bin Al-Harith and Sulaiman bin Musa reported it from Makhul with his chain, similarly}}
\hadithdefcmd{abudawud}{1270}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ عُبَيْدَةَ، يُحَدِّثُ عَنْ إِبْرَاهِيمَ، عَنِ ابْنِ مِنْجَابٍ، عَنْ قَرْثَعٍ، عَنْ أَبِي أَيُّوبَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَرْبَعٌ قَبْلَ الظُّهْرِ لَيْسَ فِيهِنَّ تَسْلِيمٌ تُفْتَحُ لَهُنَّ أَبْوَابُ السَّمَاءِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ بَلَغَنِي عَنْ يَحْيَى بْنِ سَعِيدٍ الْقَطَّانِ قَالَ لَوْ حَدَّثْتُ عَنْ عُبَيْدَةَ بِشَىْءٍ لَحَدَّثْتُ عَنْهُ بِهَذَا الْحَدِيثِ ‏.‏ قَالَ أَبُو دَاوُدَ عُبَيْدَةُ ضَعِيفٌ ‏.‏ قَالَ أَبُو دَاوُدَ ابْنُ مِنْجَابٍ هُوَ سَهْمٌ ‏.‏\hadithno{1270}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuAyyub: The Prophet (ﷺ) said: The gates of heaven are opened for four rak'ahs containing no taslim (salutation) before the noon prayer. Abu Dawud said: Yahya b. Sa'id al-Qattan said: If I were to narrate any tradition from 'Ubaidah, I would narrate this tradition. Abu Dawud said: 'Ubaidah is weak. Abu Dawud said: The name of the narrator Ibn Minjab is Sahm}}
\hadithdefcmd{abudawud}{1271}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا مُحَمَّدُ بْنُ مِهْرَانَ الْقُرَشِيُّ، حَدَّثَنِي جَدِّي أَبُو الْمُثَنَّى، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ رَحِمَ اللَّهُ امْرَأً صَلَّى قَبْلَ الْعَصْرِ أَرْبَعًا ‏"‏ ‏.‏\hadithno{1271}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) said: May Allah show mercy to a man who prays four rak'ahs before the afternoon prayer}}
\hadithdefcmd{abudawud}{1272}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، عَنْ عَلِيٍّ، عَلَيْهِ السَّلاَمُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُصَلِّي قَبْلَ الْعَصْرِ رَكْعَتَيْنِ ‏.‏\hadithno{1272}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Ali:That the Prophet (ﷺ) used to pray two rak'ahs before the 'Asr prayer}}
\hadithdefcmd{abudawud}{1273}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ بُكَيْرِ بْنِ الأَشَجِّ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، وَعَبْدَ الرَّحْمَنِ بْنَ أَزْهَرَ، وَالْمِسْوَرَ بْنَ مَخْرَمَةَ، أَرْسَلُوهُ إِلَى عَائِشَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم فَقَالُوا اقْرَأْ عَلَيْهَا السَّلاَمَ مِنَّا جَمِيعًا وَسَلْهَا عَنِ الرَّكْعَتَيْنِ بَعْدَ الْعَصْرِ وَقُلْ إِنَّا أُخْبِرْنَا أَنَّكِ تُصَلِّينَهُمَا وَقَدْ بَلَغَنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْهُمَا ‏.‏ فَدَخَلْتُ عَلَيْهَا فَبَلَّغْتُهَا مَا أَرْسَلُونِي بِهِ فَقَالَتْ سَلْ أُمَّ سَلَمَةَ ‏.‏ فَخَرَجْتُ إِلَيْهِمْ فَأَخْبَرْتُهُمْ بِقَوْلِهَا فَرَدُّونِي إِلَى أُمِّ سَلَمَةَ بِمِثْلِ مَا أَرْسَلُونِي بِهِ إِلَى عَائِشَةَ فَقَالَتْ أُمُّ سَلَمَةَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنْهُمَا ثُمَّ رَأَيْتُهُ يُصَلِّيهِمَا أَمَّا حِينَ صَلاَّهُمَا فَإِنَّهُ صَلَّى الْعَصْرَ ثُمَّ دَخَلَ وَعِنْدِي نِسْوَةٌ مِنْ بَنِي حَرَامٍ مِنَ الأَنْصَارِ فَصَلاَّهُمَا فَأَرْسَلْتُ إِلَيْهِ الْجَارِيَةَ فَقُلْتُ قُومِي بِجَنْبِهِ فَقُولِي لَهُ تَقُولُ أُمُّ سَلَمَةَ يَا رَسُولَ اللَّهِ أَسْمَعُكَ تَنْهَى عَنْ هَاتَيْنِ الرَّكْعَتَيْنِ وَأَرَاكَ تُصَلِّيهِمَا فَإِنْ أَشَارَ بِيَدِهِ فَاسْتَأْخِرِي عَنْهُ ‏.‏ قَالَتْ فَفَعَلَتِ الْجَارِيَةُ فَأَشَارَ بِيَدِهِ فَاسْتَأْخَرَتْ عَنْهُ فَلَمَّا انْصَرَفَ قَالَ ‏ "‏ يَا بِنْتَ أَبِي أُمَيَّةَ سَأَلْتِ عَنِ الرَّكْعَتَيْنِ بَعْدَ الْعَصْرِ إِنَّهُ أَتَانِي نَاسٌ مِنْ عَبْدِ الْقَيْسِ بِالإِسْلاَمِ مِنْ قَوْمِهِمْ فَشَغَلُونِي عَنِ الرَّكْعَتَيْنِ اللَّتَيْنِ بَعْدَ الظُّهْرِ فَهُمَا هَاتَانِ ‏"‏ ‏.‏\hadithno{1273}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1233) Sahih Muslim (834)}\hadithtrans{Narrated Kuraib, the client of Ibn 'Abbas:That 'Abd Allah b. Abbas, 'Abd al-Rahman b. Azhar and al-Miswar b. Makhramah sent him to 'Aishah, wife of the Prophet (ﷺ). They said: Convey our regards to her from all of us and ask her about the two rak'ahs after the 'Asr prayer, and tell her that we have been informed that she prays them, and we are told that the Messenger of Allah (ﷺ) prohibited them. I entered upon her and told her that for which they had sent me to her. She said: Ask Umm Salamah. I returned to them (Ibn 'Abbas and others) and informed them about her opinion. They sent me back to Umm Salamah with the same mission for which they had sent me to 'Aishah. Umm Salamah said: I heard the Messenger of Allah (ﷺ) prohibiting them, but later on I saw him praying them. When he prayed them, he had offered the 'Asr prayer. He then came to me while a number of women from Banu Haram from the Ansar were sitting with me. He prayed these two rak'ahs. I sent a slave girl to him and I told her: Stand beside him and tell him that Umm Salamah has asked: Messenger of Allah (ﷺ), I heard you prohibiting these two rak'ahs (after the afternoon prayer) but I see you praying them yourself. If he makes a sign with his hand, step backward from him. The slave girl did so. When he finished prayer, he said: O daughter of Abu Umayyah, you asked about the praying of two rak'ahs after the 'Asr prayer, in fact, some people of 'Abd al-Qais has come to me with the news that their people had embraced Islam. They hindered me from praying the two rak'ahs after Zuhr prayer. It is those two rak'ahs (which I offered after the 'Asr prayer)}}
\hadithdefcmd{abudawud}{1274}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ وَهْبِ بْنِ الأَجْدَعِ، عَنْ عَلِيٍّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الصَّلاَةِ بَعْدَ الْعَصْرِ إِلاَّ وَالشَّمْسُ مُرْتَفِعَةٌ ‏.‏\hadithno{1274}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ali ibn AbuTalib: The Prophet (ﷺ) prohibited to offer prayer after the afternoon prayer except at the time when the sun is high up in the sky}}
\hadithdefcmd{abudawud}{1275}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، عَنْ عَلِيٍّ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي فِي إِثْرِ كُلِّ صَلاَةٍ مَكْتُوبَةٍ رَكْعَتَيْنِ إِلاَّ الْفَجْرَ وَالْعَصْرَ ‏.‏\hadithno{1275}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: The Messenger of Allah (ﷺ) would offer two rak'ahs after every obligatory prayer except the dawn and the 'Asr prayer}}
\hadithdefcmd{abudawud}{1276}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبَانُ، حَدَّثَنَا قَتَادَةُ، عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ شَهِدَ عِنْدِي رِجَالٌ مَرْضِيُّونَ فِيهِمْ عُمَرُ بْنُ الْخَطَّابِ وَأَرْضَاهُمْ عِنْدِي عُمَرُ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ صَلاَةَ بَعْدَ صَلاَةِ الصُّبْحِ حَتَّى تَطْلُعَ الشَّمْسُ وَلاَ صَلاَةَ بَعْدَ صَلاَةِ الْعَصْرِ حَتَّى تَغْرُبَ الشَّمْسُ ‏"‏ ‏.‏\hadithno{1276}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (581) Sahih Muslim (826)}\hadithtrans{Narrated Abdullah ibn Abbas: Some reliable people testified before me, and among them was Umar ibn al-Khattab, and most reliable in my eyes was Umar: The Prophet of Allah (ﷺ) said: There is no prayer after the dawn prayer until the sun rises; and there is no prayer after the 'Asr prayer until the sun sets}}
\hadithdefcmd{abudawud}{1277}{حَدَّثَنَا الرَّبِيعُ بْنُ نَافِعٍ، حَدَّثَنَا مُحَمَّدُ بْنُ الْمُهَاجِرِ، عَنِ الْعَبَّاسِ بْنِ سَالِمٍ، عَنْ أَبِي سَلاَّمٍ، عَنْ أَبِي أُمَامَةَ، عَنْ عَمْرِو بْنِ عَبَسَةَ السُّلَمِيِّ، أَنَّهُ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَىُّ اللَّيْلِ أَسْمَعُ قَالَ ‏ "‏ جَوْفُ اللَّيْلِ الآخِرُ فَصَلِّ مَا شِئْتَ فَإِنَّ الصَّلاَةَ مَشْهُودَةٌ مَكْتُوبَةٌ حَتَّى تُصَلِّيَ الصُّبْحَ ثُمَّ أَقْصِرْ حَتَّى تَطْلُعَ الشَّمْسُ فَتَرْتَفِعَ قِيْسَ رُمْحٍ أَوْ رُمْحَيْنِ فَإِنَّهَا تَطْلُعُ بَيْنَ قَرْنَىْ شَيْطَانٍ وَتُصَلِّي لَهَا الْكُفَّارُ ثُمَّ صَلِّ مَا شِئْتَ فَإِنَّ الصَّلاَةَ مَشْهُودَةٌ مَكْتُوبَةٌ حَتَّى يَعْدِلَ الرُّمْحُ ظِلَّهُ ثُمَّ أَقْصِرْ فَإِنَّ جَهَنَّمَ تُسْجَرُ وَتُفْتَحُ أَبْوَابُهَا فَإِذَا زَاغَتِ الشَّمْسُ فَصَلِّ مَا شِئْتَ فَإِنَّ الصَّلاَةَ مَشْهُودَةٌ حَتَّى تُصَلِّيَ الْعَصْرَ ثُمَّ أَقْصِرْ حَتَّى تَغْرُبَ الشَّمْسُ فَإِنَّهَا تَغْرُبُ بَيْنَ قَرْنَىْ شَيْطَانٍ وَيُصَلِّي لَهَا الْكُفَّارُ ‏"‏ ‏.‏ وَقَصَّ حَدِيثًا طَوِيلاً قَالَ الْعَبَّاسُ هَكَذَا حَدَّثَنِي أَبُو سَلاَّمٍ عَنْ أَبِي أُمَامَةَ إِلاَّ أَنْ أُخْطِئَ شَيْئًا لاَ أُرِيدُهُ فَأَسْتَغْفِرُ اللَّهَ وَأَتُوبُ إِلَيْهِ ‏.‏\hadithno{1277}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Amr ibn Anbasah as-Sulami: I asked: Messenger of Allah, in which part of night the supplication is more likely to be accepted? He replied: In the last part: Pray as much as you like, for the prayer is attended by the angels and it is recorded till you offer the dawn prayer; then stop praying when the sun is rising till it has reached the height of one or two lances, for it rises between the two horns of the Devil, and the infidels offer prayer for it (at that time). Then pray as much as you like, because the prayer is witnessed and recorded till the shadow of a lance be- comes equal to it. Then cease prayer, for at that time the Hell-fire is heated up and doors of Hell are opened. When the sun declines, pray as much as you like, for the prayer is witnessed till you pray the afternoon prayer; then cease prayer till the sun sets, for it sets between the horns of the Devil, and (at that time) the infidels offer prayer for it. He narrated a lengthy tradition. Abbas said: AbuSalam narrated this tradition in a similar manner from AbuUmamah. If I have made a mistake unintentionally, I beg pardon of Allah and repent to Him}}
\hadithdefcmd{abudawud}{1278}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا قُدَامَةُ بْنُ مُوسَى، عَنْ أَيُّوبَ بْنِ حُصَيْنٍ، عَنْ أَبِي عَلْقَمَةَ، عَنْ يَسَارٍ، مَوْلَى ابْنِ عُمَرَ قَالَ رَآنِي ابْنُ عُمَرَ وَأَنَا أُصَلِّي، بَعْدَ طُلُوعِ الْفَجْرِ فَقَالَ يَا يَسَارُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ عَلَيْنَا وَنَحْنُ نُصَلِّي هَذِهِ الصَّلاَةَ فَقَالَ ‏ "‏ لِيُبَلِّغْ شَاهِدُكُمْ غَائِبَكُمْ لاَ تُصَلُّوا بَعْدَ الْفَجْرِ إِلاَّ سَجْدَتَيْنِ ‏"‏ ‏.‏\hadithno{1278}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: Yasar, the client of Ibn Umar, said: Ibn Umar saw me praying after the break of dawn. He said: O Yasar, the Messenger of Allah (ﷺ) came to us while we were offering this prayer. He (the Prophet) said: Those who are present should inform those who are absent: Do not offer any prayer after (the break of) dawn except two rak'ahs}}
\hadithdefcmd{abudawud}{1279}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، وَمَسْرُوقٍ، قَالاَ نَشْهَدُ عَلَى عَائِشَةَ - رضى الله عنها - أَنَّهَا قَالَتْ مَا مِنْ يَوْمٍ يَأْتِي عَلَى النَّبِيِّ صلى الله عليه وسلم إِلاَّ صَلَّى بَعْدَ الْعَصْرِ رَكْعَتَيْنِ ‏.‏\hadithno{1279}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (593) Sahih Muslim (835)}\hadithtrans{Al-Aswad and Masruq said:We bear witness that 'Aishah said: Not a day passed but the Prophet (ﷺ) prayed two rak'ahs after the 'Asr prayer}}
\hadithdefcmd{abudawud}{1280}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدٍ، حَدَّثَنَا عَمِّي، حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، عَنْ ذَكْوَانَ، مَوْلَى عَائِشَةَ أَنَّهَا حَدَّثَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي بَعْدَ الْعَصْرِ وَيَنْهَى عَنْهَا وَيُوَاصِلُ وَيَنْهَى عَنِ الْوِصَالِ ‏.‏\hadithno{1280}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Dhakwan, the client of Aisha, reported on the authority of Aisha: The Messenger of Allah (ﷺ) used to pray after the afternoon prayer but prohibited others from it; and he would fast continuously but forbid others to do so}}
\hadithdefcmd{abudawud}{1281}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، عَنِ الْحُسَيْنِ الْمُعَلِّمِ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ عَبْدِ اللَّهِ الْمُزَنِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ صَلُّوا قَبْلَ الْمَغْرِبِ رَكْعَتَيْنِ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ صَلُّوا قَبْلَ الْمَغْرِبِ رَكْعَتَيْنِ لِمَنْ شَاءَ ‏"‏ ‏.‏ خَشْيَةَ أَنْ يَتَّخِذَهَا النَّاسُ سُنَّةً ‏.‏\hadithno{1281}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (563)}\hadithtrans{Narrated 'Abd Allah al-Muzani:The Messenger of Allah (ﷺ) said: Pray two rak'ahs before the Maghrib prayer. He then said (again): Pray two rak'ahs before the Maghrib prayer, it applies to those who wish to do so. That was because he feared that the people might treat it as sunnah}}
\hadithdefcmd{abudawud}{1282}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ الْبَزَّازُ، أَخْبَرَنَا سَعِيدُ بْنُ سُلَيْمَانَ، حَدَّثَنَا مَنْصُورُ بْنُ أَبِي الأَسْوَدِ، عَنِ الْمُخْتَارِ بْنِ فُلْفُلٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ صَلَّيْتُ الرَّكْعَتَيْنِ قَبْلَ الْمَغْرِبِ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ قُلْتُ لأَنَسٍ أَرَآكُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ رَآنَا فَلَمْ يَأْمُرْنَا وَلَمْ يَنْهَنَا ‏.‏\hadithno{1282}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (836)}\hadithtrans{Narrated Anas b. Malik :I offered two rak'ahs of prayer before the Maghrib prayer (i.e. obligatory) during the time of the Messenger of Allah (ﷺ). I (narrator al-Mukhtar b. Fulful) asked Anas: Did the Messenger of Allah (ﷺ) se you ? He replied: Yes, but he neither commanded us nor forbade us (to do so)}}
\hadithdefcmd{abudawud}{1283}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنِ الْجُرَيْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بَيْنَ كُلِّ أَذَانَيْنِ صَلاَةٌ بَيْنَ كُلِّ أَذَانَيْنِ صَلاَةٌ لِمَنْ شَاءَ ‏"‏ ‏.‏\hadithno{1283}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (624) Sahih Muslim (838)}\hadithtrans{Narrated 'Abd Allah b. Mughaffal:The Messenger of Allah (ﷺ) as saying: Between the two adhans there is a prayer, between the two adhans there is prayer for one who desires (to offer)}}
\hadithdefcmd{abudawud}{1284}{حَدَّثَنَا ابْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي شُعَيْبٍ، عَنْ طَاوُسٍ، قَالَ سُئِلَ ابْنُ عُمَرَ عَنِ الرَّكْعَتَيْنِ، قَبْلَ الْمَغْرِبِ فَقَالَ مَا رَأَيْتُ أَحَدًا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم يُصَلِّيهِمَا ‏.‏ وَرَخَّصَ فِي الرَّكْعَتَيْنِ بَعْدَ الْعَصْرِ ‏.‏ قَالَ أَبُو دَاوُدَ سَمِعْتُ يَحْيَى بْنَ مَعِينٍ يَقُولُ هُوَ شُعَيْبٌ يَعْنِي وَهِمَ شُعْبَةُ فِي اسْمِهِ ‏.‏\hadithno{1284}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Tawus: Ibn 'Umar was asked about praying two rak'ahs before the Maghrib prayer. He replied: I did not see anyone praying them during the time of the Messenger of Allah (ﷺ). He (Ibn Umar) permitted to pray two rak'ahs after the Asr prayer. Abu Dawud said: I heard Yahya b. Ma'in say: The correct name of the narrator Abu Shu'aib is the Shu'aib. Shu'bah made a mistake in narrating his name}}
\hadithdefcmd{abudawud}{1285}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، عَنْ عَبَّادِ بْنِ عَبَّادٍ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، - الْمَعْنَى - عَنْ وَاصِلٍ، عَنْ يَحْيَى بْنِ عُقَيْلٍ، عَنْ يَحْيَى بْنِ يَعْمُرَ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ يُصْبِحُ عَلَى كُلِّ سُلاَمَى مِنِ ابْنِ آدَمَ صَدَقَةٌ تَسْلِيمُهُ عَلَى مَنْ لَقِيَ صَدَقَةٌ وَأَمْرُهُ بِالْمَعْرُوفِ صَدَقَةٌ وَنَهْيُهُ عَنِ الْمُنْكَرِ صَدَقَةٌ وَإِمَاطَتُهُ الأَذَى عَنِ الطَّرِيقِ صَدَقَةٌ وَبُضْعَةُ أَهْلِهِ صَدَقَةٌ وَيُجْزِئُ مِنْ ذَلِكَ كُلِّهِ رَكْعَتَانِ مِنَ الضُّحَى ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَحَدِيثُ عَبَّادٍ أَتَمُّ وَلَمْ يَذْكُرْ مُسَدَّدٌ الأَمْرَ وَالنَّهْىَ زَادَ فِي حَدِيثِهِ وَقَالَ كَذَا وَكَذَا وَزَادَ ابْنُ مَنِيعٍ فِي حَدِيثِهِ قَالُوا يَا رَسُولَ اللَّهِ أَحَدُنَا يَقْضِي شَهْوَتَهُ وَتَكُونُ لَهُ صَدَقَةٌ قَالَ ‏"‏ أَرَأَيْتَ لَوْ وَضَعَهَا فِي غَيْرِ حِلِّهَا أَلَمْ يَكُنْ يَأْثَمُ ‏"‏ ‏.‏\hadithno{1285}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Dharr: The Prophet (ﷺ) as saying: In the morning alms are due for every bone in man's body. His salutation to everyone he meets is alms, his enjoining good is alms, his forbidding what is evil is alms, the removal of harmful thing from the way is alms, to have sexual intercourse with one's wife if alms, and two rak'ahs which one prays in the Duha serve instead of that. Abu Dawud said: The tradition narrated by 'Abbad is more perfect (than the version narrated by Musaddad). Musaddad did not mention in his version "the command (of good) and the prohibition (of evil)". Instead, he added in his version saying: "Such and such." Ibn Ma'na added in his version: "They (the people) said: Messenger of Allah, how is that one of us fulfills his desire and still there are alms for him (i.e. is rewarded)? He replied: What do you think if you had unlawful sexual intercourse, would he not have been a sinner ?}}
\hadithdefcmd{abudawud}{1286}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، أَخْبَرَنَا خَالِدٌ، عَنْ وَاصِلٍ، عَنْ يَحْيَى بْنِ عُقَيْلٍ، عَنْ يَحْيَى بْنِ يَعْمُرَ، عَنْ أَبِي الأَسْوَدِ الدُّؤَلِيِّ، قَالَ بَيْنَمَا نَحْنُ عِنْدَ أَبِي ذَرٍّ قَالَ ‏"‏ يُصْبِحُ عَلَى كُلِّ سُلاَمَى مِنْ أَحَدِكُمْ فِي كُلِّ يَوْمٍ صَدَقَةٌ فَلَهُ بِكُلِّ صَلاَةٍ صَدَقَةٌ وَصِيَامٍ صَدَقَةٌ وَحَجٍّ صَدَقَةٌ وَتَسْبِيحٍ صَدَقَةٌ وَتَكْبِيرٍ صَدَقَةٌ وَتَحْمِيدٍ صَدَقَةٌ ‏"‏ ‏.‏ فَعَدَّ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ هَذِهِ الأَعْمَالِ الصَّالِحَةِ ثُمَّ قَالَ ‏"‏ يُجْزِئُ أَحَدَكُمْ مِنْ ذَلِكَ رَكْعَتَا الضُّحَى ‏"‏ ‏.‏\hadithno{1286}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (720)}\hadithtrans{Abu al-Aswad al-Dailani said:While we were present with Abu Dharr, he said: In the morning, alms are due for him, ever fast is alms, every pilgrimage is alms, every utterance of "Glory to be Allah" is alms, every utterance of "Allah is most great" is alms, every utterance of "Praise be to Allah" is alms. The Messenger of Allah (ﷺ) recounted all such good works. He then said: Two rak'ahs which one prays in the Duha serve instead of that}}
\hadithdefcmd{abudawud}{1287}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ الْمُرَادِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يَحْيَى بْنِ أَيُّوبَ، عَنْ زَبَّانَ بْنِ فَائِدٍ، عَنْ سَهْلِ بْنِ مُعَاذِ بْنِ أَنَسٍ الْجُهَنِيِّ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَعَدَ فِي مُصَلاَّهُ حِينَ يَنْصَرِفُ مِنْ صَلاَةِ الصُّبْحِ حَتَّى يُسَبِّحَ رَكْعَتَىِ الضُّحَى لاَ يَقُولُ إِلاَّ خَيْرًا غُفِرَ لَهُ خَطَايَاهُ وَإِنْ كَانَتْ أَكْثَرَ مِنْ زَبَدِ الْبَحْرِ ‏"‏ ‏.‏\hadithno{1287}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mu'adh ibn Anas al-Juhani: The Prophet (ﷺ) said: If anyone sits in his place of prayer when he finishes the dawn prayer till he prays the two rak'ahs of the forenoon, saying nothing but what is good, his sins will be forgiven even if they are more than the foam of the sea}}
\hadithdefcmd{abudawud}{1288}{حَدَّثَنَا أَبُو تَوْبَةَ الرَّبِيعُ بْنُ نَافِعٍ، حَدَّثَنَا الْهَيْثَمُ بْنُ حُمَيْدٍ، عَنْ يَحْيَى بْنِ الْحَارِثِ، عَنِ الْقَاسِمِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي أُمَامَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ صَلاَةٌ فِي أَثَرِ صَلاَةٍ لاَ لَغْوَ بَيْنَهُمَا كِتَابٌ فِي عِلِّيِّينَ ‏"‏ ‏.‏\hadithno{1288}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuUmamah: The Prophet (ﷺ) said: Prayer followed by a prayer with no idle talk between the two is recorded in Illiyyun}}
\hadithdefcmd{abudawud}{1289}{حَدَّثَنَا دَاوُدُ بْنُ رُشَيْدٍ، حَدَّثَنَا الْوَلِيدُ، عَنْ سَعِيدِ بْنِ عَبْدِ الْعَزِيزِ، عَنْ مَكْحُولٍ، عَنْ كَثِيرِ بْنِ مُرَّةَ أَبِي شَجَرَةَ، عَنْ نُعَيْمِ بْنِ هَمَّارٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَقُولُ اللَّهُ عَزَّ وَجَلَّ يَا ابْنَ آدَمَ لاَ تُعْجِزْنِي مِنْ أَرْبَعِ رَكَعَاتٍ فِي أَوَّلِ نَهَارِكَ أَكْفِكَ آخِرَهُ ‏"‏ ‏.‏\hadithno{1289}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Nu'aym ibn Hammar: I heard the Messenger of Allah (ﷺ) say: Allah, the Exalted, says: Son of Adam, do not be helpless in performing four rak'ahs for Me at the beginning of the day: I will supply what you need till the end of it}}
\hadithdefcmd{abudawud}{1290}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، وَأَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي عِيَاضُ بْنُ عَبْدِ اللَّهِ، عَنْ مَخْرَمَةَ بْنِ سُلَيْمَانَ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنْ أُمِّ هَانِئٍ بِنْتِ أَبِي طَالِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَوْمَ الْفَتْحِ صَلَّى سُبْحَةَ الضُّحَى ثَمَانِيَ رَكَعَاتٍ يُسَلِّمُ مِنْ كُلِّ رَكْعَتَيْنِ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ أَحْمَدُ بْنُ صَالِحٍ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَوْمَ الْفَتْحِ صَلَّى سُبْحَةَ الضُّحَى فَذَكَرَ مِثْلَهُ ‏.‏ قَالَ ابْنُ السَّرْحِ إِنَّ أُمَّ هَانِئٍ قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَلَمْ يَذْكُرْ سُبْحَةَ الضُّحَى بِمَعْنَاهُ ‏.‏\hadithno{1290}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Umm Hani ibn AbuTalib: The Messenger of Allah (ﷺ) prayed on the day of the Conquest (of Mecca) eight rak'ahs saluting after every two rak'ahs. Abu Dawud said: Ahmad b. Salih said that the Messenger of Allah offered prayer in the forenoon on the day of the Conquest of Mecca, and he narrated something similar. Ibn al-Sarh reported that Umm Hani said: The Messenger of Allah (ﷺ) entered upon me. This version does not mention the prayer in the forenoon}}
\hadithdefcmd{abudawud}{1291}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنِ ابْنِ أَبِي لَيْلَى، قَالَ مَا أَخْبَرَنَا أَحَدٌ، أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم صَلَّى الضُّحَى غَيْرَ أُمِّ هَانِئٍ فَإِنَّهَا ذَكَرَتْ أَنَّ النَّبِيَّ صلى الله عليه وسلم يَوْمَ فَتْحِ مَكَّةَ اغْتَسَلَ فِي بَيْتِهَا وَصَلَّى ثَمَانِيَ رَكَعَاتٍ فَلَمْ يَرَهُ أَحَدٌ صَلاَّهُنَّ بَعْدُ ‏.‏\hadithno{1291}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1103) Sahih Muslim (336 After  719)}\hadithtrans{Narrated Ibn Abi Laila:No one told us that the Prophet (ﷺ) had offered Duha prayer except Umm Hani. She said that the Prophet (ﷺ) had taken bath in her house on the day of the Conquest of Mecca and prayed eight rak'ahs. But no one saw him afterwards praying these rak'ahs}}
\hadithdefcmd{abudawud}{1292}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا الْجُرَيْرِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، قَالَ سَأَلْتُ عَائِشَةَ هَلْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي الضُّحَى فَقَالَتْ لاَ إِلاَّ أَنْ يَجِيءَ مِنْ مَغِيبِهِ ‏.‏ قُلْتُ هَلْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرِنُ بَيْنَ السُّورَتَيْنِ قَالَتْ مِنَ الْمُفَصَّلِ ‏.‏\hadithno{1292}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (717)}\hadithtrans{Narrated 'Abd Allah b. Shaqiq:I asked 'Aishah: Did the Messenger of Allah (ﷺ) pray in the Duha? She replied: No, except when he returned from his journey. I then asked: Did the Messenger of Allah (ﷺ) recite the surahs combining each other? She said: He would do so in the mufassal surahs}}
\hadithdefcmd{abudawud}{1293}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ مَا سَبَّحَ رَسُولُ اللَّهِ صلى الله عليه وسلم سُبْحَةَ الضُّحَى قَطُّ وَإِنِّي لأُسَبِّحُهَا وَإِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيَدَعُ الْعَمَلَ وَهُوَ يُحِبُّ أَنْ يَعْمَلَ بِهِ خَشْيَةَ أَنْ يَعْمَلَ بِهِ النَّاسُ فَيُفْرَضَ عَلَيْهِمْ ‏.‏\hadithno{1293}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1128) Sahih Muslim (718)}\hadithtrans{Narrated 'Aishah, wife of Prophet (ﷺ):The Messenger of Allah (ﷺ) never offered prayer in the forenoon, but I offer it. The Messenger of Allah (ﷺ) would give up an action, though he liked it to do, lest the people should continue it and it is prescribed for them}}
\hadithdefcmd{abudawud}{1294}{حَدَّثَنَا ابْنُ نُفَيْلٍ، وَأَحْمَدُ بْنُ يُونُسَ، قَالاَ حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا سِمَاكٌ، قَالَ قُلْتُ لِجَابِرِ بْنِ سَمُرَةَ أَكُنْتَ تُجَالِسُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ كَثِيرًا فَكَانَ لاَ يَقُومُ مِنْ مُصَلاَّهُ الَّذِي صَلَّى فِيهِ الْغَدَاةَ حَتَّى تَطْلُعَ الشَّمْسُ فَإِذَا طَلَعَتْ قَامَ صلى الله عليه وسلم ‏.‏\hadithno{1294}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (670)}\hadithtrans{Narrated Simak:I asked Jabir b. Samurah: Did you sit in the company of the Messenger of Allah (ﷺ) ? He replied: Yes, very often. He would not stand from the place he prayed the dawn prayer till the sunrise. When the sun rose, he would stand (to pray Duha)}}
\hadithdefcmd{abudawud}{1295}{حَدَّثَنَا عَمْرُو بْنُ مَرْزُوقٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ عَلِيِّ بْنِ عَبْدِ اللَّهِ الْبَارِقِيِّ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ صَلاَةُ اللَّيْلِ وَالنَّهَارِ مَثْنَى مَثْنَى ‏"‏ ‏.‏\hadithno{1295}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) said: Prayer by night and day should consist of pairs of rak'ahs}}
\hadithdefcmd{abudawud}{1296}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنِي عَبْدُ رَبِّهِ بْنُ سَعِيدٍ، عَنْ أَنَسِ بْنِ أَبِي أَنَسٍ، عَنْ عَبْدِ اللَّهِ بْنِ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنِ الْمُطَّلِبِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الصَّلاَةُ مَثْنَى مَثْنَى أَنْ تَشَهَّدَ فِي كُلِّ رَكْعَتَيْنِ وَأَنْ تَبَاءَسَ وَتَمَسْكَنَ وَتُقْنِعَ بِيَدَيْكَ وَتَقُولَ اللَّهُمَّ اللَّهُمَّ فَمَنْ لَمْ يَفْعَلْ ذَلِكَ فَهِيَ خِدَاجٌ ‏"‏ ‏.‏ سُئِلَ أَبُو دَاوُدَ عَنْ صَلاَةِ اللَّيْلِ مَثْنَى قَالَ إِنْ شِئْتَ مَثْنَى وَإِنْ شِئْتَ أَرْبَعًا ‏.‏\hadithno{1296}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Muttalib: The Prophet (ﷺ) said: Prayer is to be offered in two rak'ahs; and you should recite the tashahhud at the end of two rak'ahs, and express your distress and humility and raise your hands and say praying: O Allah, O Allah. He who does not do so does not offer a perfect prayer. Abu Dawud was asked about offering prayer at night in two rak'ahs. He said: They may be two if you like and four if you like}}
\hadithdefcmd{abudawud}{1297}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ بِشْرِ بْنِ الْحَكَمِ النَّيْسَابُورِيُّ، حَدَّثَنَا مُوسَى بْنُ عَبْدِ الْعَزِيزِ، حَدَّثَنَا الْحَكَمُ بْنُ أَبَانَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِلْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ ‏ "‏ يَا عَبَّاسُ يَا عَمَّاهُ أَلاَ أُعْطِيكَ أَلاَ أَمْنَحُكَ أَلاَ أَحْبُوكَ أَلاَ أَفْعَلُ بِكَ عَشْرَ خِصَالٍ إِذَا أَنْتَ فَعَلْتَ ذَلِكَ غَفَرَ اللَّهُ لَكَ ذَنْبَكَ أَوَّلَهُ وَآخِرَهُ قَدِيمَهُ وَحَدِيثَهُ خَطَأَهُ وَعَمْدَهُ صَغِيرَهُ وَكَبِيرَهُ سِرَّهُ وَعَلاَنِيَتَهُ عَشْرَ خِصَالٍ أَنْ تُصَلِّيَ أَرْبَعَ رَكَعَاتٍ تَقْرَأُ فِي كُلِّ رَكْعَةٍ فَاتِحَةَ الْكِتَابِ وَسُورَةً فَإِذَا فَرَغْتَ مِنَ الْقِرَاءَةِ فِي أَوَّلِ رَكْعَةٍ وَأَنْتَ قَائِمٌ قُلْتَ سُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ خَمْسَ عَشْرَةَ مَرَّةً ثُمَّ تَرْكَعُ فَتَقُولُهَا وَأَنْتَ رَاكِعٌ عَشْرًا ثُمَّ تَرْفَعُ رَأْسَكَ مِنَ الرُّكُوعِ فَتَقُولُهَا عَشْرًا ثُمَّ تَهْوِي سَاجِدًا فَتَقُولُهَا وَأَنْتَ سَاجِدٌ عَشْرًا ثُمَّ تَرْفَعُ رَأْسَكَ مِنَ السُّجُودِ فَتَقُولُهَا عَشْرًا ثُمَّ تَسْجُدُ فَتَقُولُهَا عَشْرًا ثُمَّ تَرْفَعُ رَأْسَكَ فَتَقُولُهَا عَشْرًا فَذَلِكَ خَمْسٌ وَسَبْعُونَ فِي كُلِّ رَكْعَةٍ تَفْعَلُ ذَلِكَ فِي أَرْبَعِ رَكَعَاتٍ إِنِ اسْتَطَعْتَ أَنْ تُصَلِّيَهَا فِي كُلِّ يَوْمٍ مَرَّةً فَافْعَلْ فَإِنْ لَمْ تَفْعَلْ فَفِي كُلِّ جُمُعَةٍ مَرَّةً فَإِنْ لَمْ تَفْعَلْ فَفِي كُلِّ شَهْرٍ مَرَّةً فَإِنْ لَمْ تَفْعَلْ فَفِي كُلِّ سَنَةٍ مَرَّةً فَإِنْ لَمْ تَفْعَلْ فَفِي عُمُرِكَ مَرَّةً ‏"‏ ‏.‏\hadithno{1297}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah Ibn Abbas: The Messenger of Allah (ﷺ) said to al-Abbas ibn AbdulMuttalib: Abbas, my uncle, shall I not give you, shall I not present to you, shall I not donate to you, shall I not produce for you ten things? If you act upon them, Allah will forgive you your sins, first and last, old and new, involuntary and voluntary, small and great, secret and open. These are the ten things: you should pray four rak'ahs, reciting in each one Fatihat al-Kitab and a surah. When you finish the recitation of the first rak'ah you should say fifteen times while standing: "Glory be to Allah", "Praise be to Allah", "There is no god but Allah", "Allah is most great". Then you should bow and say it ten times while bowing. Then you should raise your head after bowing and say it ten times. Then you should kneel down in prostration and say it ten times while prostrating yourself. Then you should raise your head after prostration and say it ten times. Then you should prostrate yourself and say it ten times. Then you should raise your head after prostrating and say it ten times in every rak'ah. You should do that in four rak'ahs. If you can observe it once daily, do so; if not, then once weekly; if not, then once a month; if not, then once a year; if not, then once in your lifetime}}
\hadithdefcmd{abudawud}{1298}{حَدَّثَنَا مُحَمَّدُ بْنُ سُفْيَانَ الأُبُلِّيُّ، حَدَّثَنَا حَبَّانُ بْنُ هِلاَلٍ أَبُو حَبِيبٍ، حَدَّثَنَا مَهْدِيُّ بْنُ مَيْمُونٍ، حَدَّثَنَا عَمْرُو بْنُ مَالِكٍ، عَنْ أَبِي الْجَوْزَاءِ، قَالَ حَدَّثَنِي رَجُلٌ، كَانَتْ لَهُ صُحْبَةٌ يُرَوْنَ أَنَّهُ عَبْدُ اللَّهِ بْنُ عَمْرٍو قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ ائْتِنِي غَدًا أَحْبُوكَ وَأُثِيبُكَ وَأُعْطِيكَ ‏"‏ ‏.‏ حَتَّى ظَنَنْتُ أَنَّهُ يُعْطِينِي عَطِيَّةً قَالَ ‏"‏ إِذَا زَالَ النَّهَارُ فَقُمْ فَصَلِّ أَرْبَعَ رَكَعَاتٍ ‏"‏ ‏.‏ فَذَكَرَ نَحْوَهُ قَالَ ‏"‏ تَرْفَعُ رَأْسَكَ - يَعْنِي مِنَ السَّجْدَةِ الثَّانِيَةِ - فَاسْتَوِ جَالِسًا وَلاَ تَقُمْ حَتَّى تُسَبِّحَ عَشْرًا وَتَحْمَدَ عَشْرًا وَتُكَبِّرَ عَشْرًا وَتُهَلِّلَ عَشْرًا ثُمَّ تَصْنَعُ ذَلِكَ فِي الأَرْبَعِ رَكَعَاتٍ ‏"‏ ‏.‏ قَالَ ‏"‏ فَإِنَّكَ لَوْ كُنْتَ أَعْظَمَ أَهْلِ الأَرْضِ ذَنْبًا غُفِرَ لَكَ بِذَلِكَ ‏"‏ ‏.‏ قُلْتُ فَإِنْ لَمْ أَسْتَطِعْ أَنْ أُصَلِّيَهَا تِلْكَ السَّاعَةَ قَالَ ‏"‏ صَلِّهَا مِنَ اللَّيْلِ وَالنَّهَارِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ حَبَّانُ بْنُ هِلاَلٍ خَالُ هِلاَلٍ الرَّائِيِّ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ الْمُسْتَمِرُّ بْنُ الرَّيَّانِ عَنْ أَبِي الْجَوْزَاءِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو مَوْقُوفًا وَرَوَاهُ رَوْحُ بْنُ الْمُسَيَّبِ وَجَعْفَرُ بْنُ سُلَيْمَانَ عَنْ عَمْرِو بْنِ مَالِكٍ النُّكْرِيِّ عَنْ أَبِي الْجَوْزَاءِ عَنِ ابْنِ عَبَّاسٍ قَوْلُهُ وَقَالَ فِي حَدِيثِ رَوْحٍ فَقَالَ حَدِيثُ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1298}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Amr: AbulJawza' said: A man who attended the company of the Prophet (ﷺ) narrated to me (it is thought that he was Abdullah ibn Amr): The Prophet (ﷺ) said to me: Come to me tomorrow; I shall give you something, I shall give you something, I shall reward you something, I shall donate something to you. I thought that he would give me some present. He said (to me when I came to him): When the day declines, stand up and pray four rak'ahs. He then narrated something similar. This version adds: Do not stand until you glorify Allah ten times, and praise Him ten times, and exalt Him ten times, and say, "There is no god but Allah" ten times. Then you should do that in four rak'ahs. If you are the greatest sinner on earth, you will be forgiven (by Allah) on account of this (prayer). I asked: If I cannot pray this the appointed hour, (what should I do)? He replied: Pray that by night or by day (at any time). Abu Dawud said: Habban b. Hilal is the maternal uncle of Hilal al-Ra'i. Abu Dawud said: This tradition has been narrated by al-Mustamir b. al-Riyyan from Ibn al-Jawza' from 'Abd Allah b. 'Amr without referring to the Prophet (ﷺ), - narrated as a statement of 'Abd Allah b. 'Amr himself (mauquf). This has also been narrated by Rawh b. al-Musayyab, and Ja'far b. Sulaiman from 'Amr b. Malik al-Nakri from Abu al-Jauza' from Ibn 'Abbas as his own statement (and not the statement of the Prophet). But the version of Rawh has the words: "The tradition of the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{1299}{حَدَّثَنَا أَبُو تَوْبَةَ الرَّبِيعُ بْنُ نَافِعٍ، حَدَّثَنَا مُحَمَّدُ بْنُ مُهَاجِرٍ، عَنْ عُرْوَةَ بْنِ، رُوَيْمٍ حَدَّثَنِي الأَنْصَارِيُّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِجَعْفَرٍ بِهَذَا الْحَدِيثِ فَذَكَرَ نَحْوَهُمْ قَالَ فِي السَّجْدَةِ الثَّانِيَةِ مِنَ الرَّكْعَةِ الأُولَى كَمَا قَالَ فِي حَدِيثِ مَهْدِيِّ بْنِ مَيْمُونٍ ‏.‏\hadithno{1299}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Urwah b. Ruwaim:That an al-Ansari narrated to him: The Messenger of Allah (ﷺ) said to Ja'far. He then narrated the tradition in like manner. This version has the words: "In the second prostration of the first rak'ah" in addition to the words transmitted by Mahdi b. Maimun (in the previous tradition)}}
\hadithdefcmd{abudawud}{1300}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي الأَسْوَدِ، حَدَّثَنِي أَبُو مُطَرِّفٍ، مُحَمَّدُ بْنُ أَبِي الْوَزِيرِ حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى الْفِطْرِيُّ، عَنْ سَعْدِ بْنِ إِسْحَاقَ بْنِ كَعْبِ بْنِ عُجْرَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَتَى مَسْجِدَ بَنِي عَبْدِ الأَشْهَلِ فَصَلَّى فِيهِ الْمَغْرِبَ فَلَمَّا قَضَوْا صَلاَتَهُمْ رَآهُمْ يُسَبِّحُونَ بَعْدَهَا فَقَالَ ‏ "‏ هَذِهِ صَلاَةُ الْبُيُوتِ ‏"‏ ‏.‏\hadithno{1300}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ka'b ibn Ujrah: The Prophet (ﷺ) came to the mosque of Banu AbdulAshhal. He prayed the sunset prayer there. When they finished the prayer, he saw them praying the supererogatory prayer after it. He said: This is the prayer to be offered in the houses}}
\hadithdefcmd{abudawud}{1301}{حَدَّثَنَا حُسَيْنُ بْنُ عَبْدِ الرَّحْمَنِ الْجَرْجَرَائِيُّ، حَدَّثَنَا طَلْقُ بْنُ غَنَّامٍ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ اللَّهِ، عَنْ جَعْفَرِ بْنِ أَبِي الْمُغِيرَةِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُطِيلُ الْقِرَاءَةَ فِي الرَّكْعَتَيْنِ بَعْدَ الْمَغْرِبِ حَتَّى يَتَفَرَّقَ أَهْلُ الْمَسْجِدِ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ نَصْرٌ الْمُجَدَّرُ عَنْ يَعْقُوبَ الْقُمِّيِّ وَأَسْنَدَهُ مِثْلَهُ ‏.‏ قَالَ أَبُو دَاوُدَ حَدَّثَنَاهُ مُحَمَّدُ بْنُ عِيسَى بْنِ الطَّبَّاعِ حَدَّثَنَا نَصْرٌ الْمُجَدَّرُ عَنْ يَعْقُوبَ مِثْلَهُ ‏.‏\hadithno{1301}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) used to prolong the recitation of the Qur'an in the two rak'ahs after the sunset prayer until the people praying in the mosque dispersed. Abu Dawud said: This has been reported by Nasr al-Mujaddir from Ya'qub al-Qummi with the same chain of narrators. Abu Dawud said: Muhammad b. 'Isa b. al-tabba' transmitted from Nasr al-Mujaddir from Ya'qub in like manner}}
\hadithdefcmd{abudawud}{1302}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، وَسُلَيْمَانُ بْنُ دَاوُدَ الْعَتَكِيُّ، قَالاَ حَدَّثَنَا يَعْقُوبُ، عَنْ جَعْفَرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ مُرْسَلٌ ‏.‏ قَالَ أَبُو دَاوُدَ سَمِعْتُ مُحَمَّدَ بْنَ حُمَيْدٍ يَقُولُ سَمِعْتُ يَعْقُوبَ يَقُولُ كُلُّ شَىْءٍ حَدَّثْتُكُمْ عَنْ جَعْفَرٍ عَنْ سَعِيدِ بْنِ جُبَيْرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم فَهُوَ مُسْنَدٌ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1302}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Sa'id b. Jubair: This tradition from the Prophet (ﷺ) without mentioning the name of the Companion in the chain (in the mursal form). Abu dawud said: I heard Muhammad b. Humaid say: I heard Ya'qub say: Anything I narrated to you from Ja'far on the authority of Sa'id b. Jubair from the Prophet (ﷺ) is directly coming from Ibn Abbas from the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{1303}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ الْعُكْلِيُّ، حَدَّثَنِي مَالِكُ بْنُ مِغْوَلٍ، حَدَّثَنِي مُقَاتِلُ بْنُ بَشِيرٍ الْعِجْلِيُّ، عَنْ شُرَيْحِ بْنِ هَانِئٍ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَ سَأَلْتُهَا عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ مَا صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الْعِشَاءَ قَطُّ فَدَخَلَ عَلَىَّ إِلاَّ صَلَّى أَرْبَعَ رَكَعَاتٍ أَوْ سِتَّ رَكَعَاتٍ وَلَقَدْ مُطِرْنَا مَرَّةً بِاللَّيْلِ فَطَرَحْنَا لَهُ نِطْعًا فَكَأَنِّي أَنْظُرُ إِلَى ثُقْبٍ فِيهِ يَنْبُعُ الْمَاءُ مِنْهُ وَمَا رَأَيْتُهُ مُتَّقِيًا الأَرْضَ بِشَىْءٍ مِنْ ثِيَابِهِ قَطُّ ‏.‏\hadithno{1303}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Shurayh ibn Hani said: I asked Aisha about the prayer of the Messenger of Allah (ﷺ). She said: The Messenger of Allah (ﷺ) never offered the night prayer and thereafter came to me but he offered four or six rak'ahs of prayer. One night the rain fell, so we spread a piece of leather (for his prayer), and now I see as if there is a hole in it from which the water is flowing. I never saw him protecting his clothes from the earth (as he did on that occasion)}}
\hadithdefcmd{abudawud}{1304}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ الْمَرْوَزِيُّ ابْنُ شَبُّويَةَ، حَدَّثَنِي عَلِيُّ بْنُ حُسَيْنٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ فِي الْمُزَّمِّلِ ‏\{‏ قُمِ اللَّيْلَ إِلاَّ قَلِيلاً * نِصْفَهُ ‏\}‏ نَسَخَتْهَا الآيَةُ الَّتِي فِيهَا ‏\{‏ عَلِمَ أَنْ لَنْ تُحْصُوهُ فَتَابَ عَلَيْكُمْ فَاقْرَءُوا مَا تَيَسَّرَ مِنَ الْقُرْآنِ ‏\}‏ وَنَاشِئَةُ اللَّيْلِ أَوَّلُهُ وَكَانَتْ صَلاَتُهُمْ لأَوَّلِ اللَّيْلِ يَقُولُ هُوَ أَجْدَرُ أَنْ تُحْصُوا مَا فَرَضَ اللَّهُ عَلَيْكُمْ مِنْ قِيَامِ اللَّيْلِ وَذَلِكَ أَنَّ الإِنْسَانَ إِذَا نَامَ لَمْ يَدْرِ مَتَى يَسْتَيْقِظُ وَقَوْلُهُ ‏\{‏ أَقْوَمُ قِيلاً ‏\}‏ هُوَ أَجْدَرُ أَنْ يُفْقَهَ فِي الْقُرْآنِ وَقَوْلُهُ ‏\{‏ إِنَّ لَكَ فِي النَّهَارِ سَبْحًا طَوِيلاً ‏\}‏ يَقُولُ فَرَاغًا طَوِيلاً ‏.‏\hadithno{1304}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah Ibn Abbas: In Surat al-Muzzammil (73), the verse: "Keep vigil at night but a little, a half thereof" (2-3) has been abrogated by the following verse: "He knoweth that ye count it not, and turneth unto you in mercy. Recite then of the Qur'an that which is easy for you" (v.20). The phrase "the vigil of the night" (nashi'at al-layl) means the early hours of the night. They (the companions) would pray (the tahajjud prayer) in the early hours of the night. He (Ibn Abbas) says: It is advisable to offer the prayer at night (tahajjud), prescribed by Allah for you (in the early hours of the night). This is because when a person sleeps, he does not know when he will awake. The words "speech more certain" (aqwamu qilan) means that this time is more suitable for the understanding of the Qur'an. He says: The verse: "Lo, thou hast by day a chain of business" (v.7) means engagement for long periods (in the day's work)}}
\hadithdefcmd{abudawud}{1305}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، - يَعْنِي الْمَرْوَزِيَّ - حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، عَنْ سِمَاكٍ الْحَنَفِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا نَزَلَتْ أَوَّلُ الْمُزَّمِّلِ كَانُوا يَقُومُونَ نَحْوًا مِنْ قِيَامِهِمْ فِي شَهْرِ رَمَضَانَ حَتَّى نَزَلَ آخِرُهَا وَكَانَ بَيْنَ أَوَّلِهَا وَآخِرِهَا سَنَةٌ ‏.‏\hadithno{1305}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ibn 'Abbas:When the opening verses of Surah Al-muzammil was revealed, the Companions would pray as long as they would pray during Ramadan until its last verses were revealed. The period between the revelation of its opening and the last verses was one year}}
\hadithdefcmd{abudawud}{1306}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَعْقِدُ الشَّيْطَانُ عَلَى قَافِيَةِ رَأْسِ أَحَدِكُمْ إِذَا هُوَ نَامَ ثَلاَثَ عُقَدٍ يَضْرِبُ مَكَانَ كُلِّ عُقْدَةٍ عَلَيْكَ لَيْلٌ طَوِيلٌ فَارْقُدْ فَإِنِ اسْتَيْقَظَ فَذَكَرَ اللَّهَ انْحَلَّتْ عُقْدَةٌ فَإِنْ تَوَضَّأَ انْحَلَّتْ عُقْدَةٌ فَإِنْ صَلَّى انْحَلَّتْ عُقْدَةٌ فَأَصْبَحَ نَشِيطًا طَيِّبَ النَّفْسِ وَإِلاَّ أَصْبَحَ خَبِيثَ النَّفْسِ كَسْلاَنَ ‏"‏ ‏.‏\hadithno{1306}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1142) Sahih Muslim (776)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: When one you sleeps, the devil ties three knots at the back of his neck, sealing every knot with, "You have a long night, so sleep." So if one awakes and mentions Allah, a knot will be loosened; if he performs ablution another knot will be loosened; and if he prays, the third knot will be loosened; and in the morning he will be active and in good spirits; otherwise he will be in bad spirits and sluggish}}
\hadithdefcmd{abudawud}{1307}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ يَزِيدَ بْنِ خُمَيْرٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي قَيْسٍ، يَقُولُ قَالَتْ عَائِشَةُ رضى الله عنها لاَ تَدَعْ قِيَامَ اللَّيْلِ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ لاَ يَدَعُهُ وَكَانَ إِذَا مَرِضَ أَوْ كَسِلَ صَلَّى قَاعِدًا ‏.‏\hadithno{1307}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Do not give up prayer at night, for the Messenger of Allah (ﷺ) would not leave it. Whenever he fell ill or lethargic, he would offer it sitting}}
\hadithdefcmd{abudawud}{1308}{حَدَّثَنَا ابْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا ابْنُ عَجْلاَنَ، عَنِ الْقَعْقَاعِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ رَحِمَ اللَّهُ رَجُلاً قَامَ مِنَ اللَّيْلِ فَصَلَّى وَأَيْقَظَ امْرَأَتَهُ فَإِنْ أَبَتْ نَضَحَ فِي وَجْهِهَا الْمَاءَ رَحِمَ اللَّهُ امْرَأَةً قَامَتْ مِنَ اللَّيْلِ فَصَلَّتْ وَأَيْقَظَتْ زَوْجَهَا فَإِنْ أَبَى نَضَحَتْ فِي وَجْهِهِ الْمَاءَ ‏"‏ ‏.‏\hadithno{1308}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: May Allah have mercy on a man who gets up at night and prays, and awakens his wife; if she refuses, he should sprinkle water on her face. May Allah have mercy on a woman who gets up at night and prays, and awakens her husband; if he refuses, she would sprinkle water on his face}}
\hadithdefcmd{abudawud}{1309}{حَدَّثَنَا ابْنُ كَثِيرٍ، حَدَّثَنَا سُفْيَانُ، عَنْ مِسْعَرٍ، عَنْ عَلِيِّ بْنِ الأَقْمَرِ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمِ بْنِ بَزِيعٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ شَيْبَانَ، عَنِ الأَعْمَشِ، عَنْ عَلِيِّ بْنِ الأَقْمَرِ، - الْمَعْنَى - عَنِ الأَغَرِّ، عَنْ أَبِي سَعِيدٍ، وَأَبِي، هُرَيْرَةَ قَالاَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَيْقَظَ الرَّجُلُ أَهْلَهُ مِنَ اللَّيْلِ فَصَلَّيَا أَوْ صَلَّى رَكْعَتَيْنِ جَمِيعًا كُتِبَا فِي الذَّاكِرِينَ وَالذَّاكِرَاتِ ‏"‏ ‏.‏ وَلَمْ يَرْفَعْهُ ابْنُ كَثِيرٍ وَلاَ ذَكَرَ أَبَا هُرَيْرَةَ جَعَلَهُ كَلاَمَ أَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ ابْنُ مَهْدِيٍّ عَنْ سُفْيَانَ قَالَ وَأُرَاهُ ذَكَرَ أَبَا هُرَيْرَةَ ‏.‏ قَالَ أَبُو دَاوُدَ وَحَدِيثُ سُفْيَانَ مَوْقُوفٌ ‏.‏\hadithno{1309}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id and AbuHurayrah: The Prophet (ﷺ) said: If a man awakens his wife at night, and then both pray or both offer two rak'ahs together, the (name of the )man will be recorded among those who mention the name of Allah, and the (name of the) woman will be recorded among those who mention the name of Allah. Ibn Kathir did not narrate this tradition as a statement of the Prophet (ﷺ), but he reported it as a statement of Abu Sa'id. Abu Dawud said: This tradition has been narrated by Ibn Mahdi from Sufyan and I think he mentioned the name of Sufyan. He also said: The tradition transmitted by Sufyan is a statement of the Companion (and not that of the Prophet)}}
\hadithdefcmd{abudawud}{1310}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا نَعَسَ أَحَدُكُمْ فِي الصَّلاَةِ فَلْيَرْقُدْ حَتَّى يَذْهَبَ عَنْهُ النَّوْمُ فَإِنَّ أَحَدَكُمْ إِذَا صَلَّى وَهُوَ نَاعِسٌ لَعَلَّهُ يَذْهَبُ يَسْتَغْفِرُ فَيَسُبَّ نَفْسَهُ ‏"‏ ‏.‏\hadithno{1310}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (212) Sahih Muslim (786)}\hadithtrans{Narrated 'Aishah, wife of Prophet (ﷺ):When one of you dozes in prayer he should sleep till his sleep is gone, for when one of you prays while he is dozing, perhaps he might curse himself if he begs pardon of Allah}}
\hadithdefcmd{abudawud}{1311}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا قَامَ أَحَدُكُمْ مِنَ اللَّيْلِ فَاسْتَعْجَمَ الْقُرْآنُ عَلَى لِسَانِهِ فَلَمْ يَدْرِ مَا يَقُولُ فَلْيَضْطَجِعْ ‏"‏ ‏.‏\hadithno{1311}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (787)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: When one of you gets up by night (to pray), and falters in reciting the Qur'an (due to sleep), and he does not understand what he utters, he should sleep}}
\hadithdefcmd{abudawud}{1312}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ، وَهَارُونُ بْنُ عَبَّادٍ الأَزْدِيُّ، أَنَّ إِسْمَاعِيلَ بْنَ إِبْرَاهِيمَ، حَدَّثَهُمْ حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَنَسٍ، قَالَ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَسْجِدَ وَحَبْلٌ مَمْدُودٌ بَيْنَ سَارِيَتَيْنِ فَقَالَ ‏"‏ مَا هَذَا الْحَبْلُ ‏"‏ ‏.‏ فَقِيلَ يَا رَسُولَ اللَّهِ هَذِهِ حَمْنَةُ بِنْتُ جَحْشٍ تُصَلِّي فَإِذَا أَعْيَتْ تَعَلَّقَتْ بِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لِتُصَلِّ مَا أَطَاقَتْ فَإِذَا أَعْيَتْ فَلْتَجْلِسْ ‏"‏ ‏.‏ قَالَ زِيَادٌ فَقَالَ ‏"‏ مَا هَذَا ‏"‏ ‏.‏ فَقَالُوا لِزَيْنَبَ تُصَلِّي فَإِذَا كَسِلَتْ أَوْ فَتَرَتْ أَمْسَكَتْ بِهِ ‏.‏ فَقَالَ ‏"‏ حُلُّوهُ ‏"‏ ‏.‏ فَقَالَ ‏"‏ لِيُصَلِّ أَحَدُكُمْ نَشَاطَهُ فَإِذَا كَسِلَ أَوْ فَتَرَ فَلْيَقْعُدْ ‏"‏ ‏.‏\hadithno{1312}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1150) Sahih Muslim (784)}\hadithtrans{Narrated Anas: The Messenger of Allah (ﷺ) entered the mosque (and saw that) a rope tied between two pillars. He asked: What is this rope (for) ? The people told him: This is (for) Hamnah b. Jahsh who prays (here). When she is tired, she reclines on it. The Messenger of Allah (ﷺ) said: She should pray as much as she has strength. When she is tired, she should sit down. This version of Ziyad has: He said: What is this ? The people told him: This is for Zainab who prays. When she becomes lazy, or is tired, she holds it. He said: Undo it. One of you should pray in good spirits. When he is lazy or tired, he should sit down}}
\hadithdefcmd{abudawud}{1313}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو صَفْوَانَ عَبْدُ اللَّهِ بْنُ سَعِيدِ بْنِ عَبْدِ الْمَلِكِ بْنِ مَرْوَانَ، ح وَحَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ، وَمُحَمَّدُ بْنُ سَلَمَةَ الْمُرَادِيُّ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، - الْمَعْنَى - عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، أَنَّ السَّائِبَ بْنَ يَزِيدَ، وَعُبَيْدَ اللَّهِ، أَخْبَرَاهُ أَنَّ عَبْدَ الرَّحْمَنِ بْنَ عَبْدٍ قَالاَ عَنِ ابْنِ وَهْبِ بْنِ عَبْدٍ الْقَارِيِّ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ نَامَ عَنْ حِزْبِهِ أَوْ عَنْ شَىْءٍ مِنْهُ فَقَرَأَهُ مَا بَيْنَ صَلاَةِ الْفَجْرِ وَصَلاَةِ الظُّهْرِ كُتِبَ لَهُ كَأَنَّمَا قَرَأَهُ مِنَ اللَّيْلِ ‏"‏ ‏.‏\hadithno{1313}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (747)}\hadithtrans{Narrated 'Umar bin Al-Khattab:The Messenger of Allah (ﷺ) as saying: He who misses him daily round of recital or part of it due to sleep and he recites it between the dawn and the noon prayers, will be reckoned as if he recited it at night}}
\hadithdefcmd{abudawud}{1314}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ رَجُلٍ، عِنْدَهُ رَضِيٍّ أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنِ امْرِئٍ تَكُونُ لَهُ صَلاَةٌ بِلَيْلٍ يَغْلِبُهُ عَلَيْهَا نَوْمٌ إِلاَّ كُتِبَ لَهُ أَجْرُ صَلاَتِهِ وَكَانَ نَوْمُهُ عَلَيْهِ صَدَقَةً ‏"‏ ‏.‏\hadithno{1314}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Prophet (ﷺ) said: Any person who offers prayer at night regularly but (on a certain night) he is dominated by sleep will be given the reward of praying. His sleep will be almsgiving}}
\hadithdefcmd{abudawud}{1315}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، وَعَنْ أَبِي عَبْدِ اللَّهِ الأَغَرِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَنْزِلُ رَبُّنَا تَبَارَكَ وَتَعَالَى كُلَّ لَيْلَةٍ إِلَى سَمَاءِ الدُّنْيَا حِينَ يَبْقَى ثُلُثُ اللَّيْلِ الآخِرُ فَيَقُولُ مَنْ يَدْعُونِي فَأَسْتَجِيبَ لَهُ مَنْ يَسْأَلُنِي فَأُعْطِيَهُ مَنْ يَسْتَغْفِرُنِي فَأَغْفِرَ لَهُ ‏"‏ ‏.‏\hadithno{1315}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1145) Sahih Muslim (758)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: Our Lord who is blessed and exalted descends every night to the lowest heaven when the last one-third of the night remains, and says: Who supplicated Me so that I may answer him ? Who asks of Me so that I may give to him ? Who asks My forgiveness so that I may forgive him ?}}
\hadithdefcmd{abudawud}{1316}{حَدَّثَنَا حُسَيْنُ بْنُ يَزِيدَ الْكُوفِيُّ، حَدَّثَنَا حَفْصٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ إِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيُوقِظُهُ اللَّهُ عَزَّ وَجَلَّ بِاللَّيْلِ فَمَا يَجِيءُ السَّحَرُ حَتَّى يَفْرُغَ مِنْ حِزْبِهِ ‏.‏\hadithno{1316}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Aishah:Allah, the Exalted, would awaken the Messenger of Allah (ﷺ) at night. When the dawn came, he would his finish daily round of recital}}
\hadithdefcmd{abudawud}{1317}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، حَدَّثَنَا أَبُو الأَحْوَصِ، ح وَحَدَّثَنَا هَنَّادٌ، عَنْ أَبِي الأَحْوَصِ، - وَهَذَا حَدِيثُ إِبْرَاهِيمَ - عَنْ أَشْعَثَ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، قَالَ سَأَلْتُ عَائِشَةَ - رضى الله عنها - عَنْ صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ لَهَا أَىُّ حِينٍ كَانَ يُصَلِّي قَالَتْ كَانَ إِذَا سَمِعَ الصُّرَاخَ قَامَ فَصَلَّى ‏.‏\hadithno{1317}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1132) Sahih Muslim (741)}\hadithtrans{Masruq said:I asked 'Aishah about the prayer of the Messenger of Allah (ﷺ), and I said to her: At what time he prayed at night ? She said: When he heard the cock crow, he got up and prayed}}
\hadithdefcmd{abudawud}{1318}{حَدَّثَنَا أَبُو تَوْبَةَ، عَنْ إِبْرَاهِيمَ بْنِ سَعْدٍ، عَنْ أَبِيهِ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، قَالَتْ ‏:‏ مَا أَلْفَاهُ السَّحَرُ عِنْدِي إِلاَّ نَائِمًا، تَعْنِي النَّبِيَّ صلى الله عليه وسلم ‏.‏\hadithno{1318}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1133) Sahih Muslim (742)}\hadithtrans{Narrated 'Aishah:When he was with me he would sleep at dawn. By this she referred to the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{1319}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا، عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ الدُّؤَلِيِّ، عَنْ عَبْدِ الْعَزِيزِ بْنِ أَخِي، حُذَيْفَةَ عَنْ حُذَيْفَةَ، قَالَ ‏:‏ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا حَزَبَهُ أَمْرٌ صَلَّى ‏.‏\hadithno{1319}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Hudhaifah said:When anything distressed the Prophet (ﷺ), he prayed}}
\hadithdefcmd{abudawud}{1320}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْهِقْلُ بْنُ زِيَادٍ السَّكْسَكِيُّ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، قَالَ سَمِعْتُ رَبِيعَةَ بْنَ كَعْبٍ الأَسْلَمِيَّ، يَقُولُ ‏:‏ كُنْتُ أَبِيتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم آتِيهِ بِوَضُوئِهِ وَبِحَاجَتِهِ، فَقَالَ ‏:‏ ‏"‏ سَلْنِي ‏"‏ ‏.‏ فَقُلْتُ ‏:‏ مُرَافَقَتَكَ فِي الْجَنَّةِ ‏.‏ قَالَ ‏:‏ ‏"‏ أَوَغَيْرَ ذَلِكَ ‏"‏ ‏.‏ قُلْتُ ‏:‏ هُوَ ذَاكَ ‏.‏ قَالَ ‏:‏ ‏"‏ فَأَعِنِّي عَلَى نَفْسِكَ بِكَثْرَةِ السُّجُودِ ‏"‏ ‏.‏\hadithno{1320}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (489)}\hadithtrans{Narrated Rab'iah b. Ka'b al-Aslami:I used to live with the Messenger of Allah (ﷺ) at night. I would bring water for his ablution and his need. He asked: Ask me. I said: Your company in Paradise. He said: Is there anything other than that ? I said: It is only that. He said: Help me for yourself by making prostrations abundantly}}
\hadithdefcmd{abudawud}{1321}{حَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، فِي هَذِهِ الآيَةِ ‏\{‏ تَتَجَافَى جُنُوبُهُمْ عَنِ الْمَضَاجِعِ، يَدْعُونَ رَبَّهُمْ خَوْفًا وَطَمَعًا وَمِمَّا رَزَقْنَاهُمْ يُنْفِقُونَ ‏\}‏ قَالَ ‏:‏ كَانُوا يَتَيَقَّظُونَ مَا بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ يُصَلُّونَ، وَكَانَ الْحَسَنُ يَقُولُ ‏:‏ قِيَامُ اللَّيْلِ ‏.‏\hadithno{1321}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Anas b. Malik said (explaining the meaning of the Qur'anic verse "Who forsake their beds to cry unto their Lord in fear and hope, and spend of what We have bestowed on them" (32:16). The people used to remain awake between the sunset and the night prayers and would pray. Al-Hasan used to say:(This verse means) the prayer and vigil at night}}
\hadithdefcmd{abudawud}{1322}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، فِي قَوْلِهِ جَلَّ وَعَزَّ ‏\{‏ كَانُوا قَلِيلاً مِنَ اللَّيْلِ مَا يَهْجَعُونَ ‏\}‏ قَالَ ‏:‏ كَانُوا يُصَلُّونَ فِيمَا بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ، زَادَ فِي حَدِيثِ يَحْيَى ‏:‏ وَكَذَلِكَ ‏\{‏ تَتَجَافَى جُنُوبُهُمْ ‏\}‏ ‏.‏\hadithno{1322}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Anas said (explaining the meaning) of the following Qur'anic verse "They used to sleep but little of the night" (51:17):They (the people) used to pray between the Maghrib and 'Isha. The version of Yahya adds: The verse tatajafa junubuhum also means so}}
\hadithdefcmd{abudawud}{1323}{حَدَّثَنَا الرَّبِيعُ بْنُ نَافِعٍ أَبُو تَوْبَةَ، حَدَّثَنَا سُلَيْمَانُ بْنُ حَيَّانَ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ إِذَا قَامَ أَحَدُكُمْ مِنَ اللَّيْلِ فَلْيُصَلِّ رَكْعَتَيْنِ خَفِيفَتَيْنِ ‏"‏ ‏.‏\hadithno{1323}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Sahih Muquf; Zubair Ali Zai: Sahih Muslim (768)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: When one of you gets up at night, he should begin the prayer with two short rak'ahs}}
\hadithdefcmd{abudawud}{1324}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، حَدَّثَنَا إِبْرَاهِيمُ، - يَعْنِي ابْنَ خَالِدٍ - عَنْ رَبَاحِ بْنِ زَيْدٍ، عَنْ مَعْمَرٍ، عَنْ أَيُّوبَ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ ‏:‏ ‏"‏ إِذَا ‏"‏ ‏.‏ بِمَعْنَاهُ زَادَ ‏:‏ ‏"‏ ثُمَّ لْيُطَوِّلْ بَعْدُ مَا شَاءَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ رَوَى هَذَا الْحَدِيثَ حَمَّادُ بْنُ سَلَمَةَ وَزُهَيْرُ بْنُ مُعَاوِيَةَ وَجَمَاعَةٌ عَنْ هِشَامٍ عَنْ مُحَمَّدٍ أَوْقَفُوهُ عَلَى أَبِي هُرَيْرَةَ، وَكَذَلِكَ رَوَاهُ أَيُّوبُ وَابْنُ عَوْنٍ أَوْقَفُوهُ عَلَى أَبِي هُرَيْرَةَ، وَرَوَاهُ ابْنُ عَوْنٍ عَنْ مُحَمَّدٍ قَالَ ‏:‏ فِيهِمَا تَجَوَّزْ ‏.‏\hadithno{1324}\hadithgrade{Al-Albani: Sahih Muquf; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Muquf; Zubair Ali Zai: Sahih}\hadithtrans{This tradition has also been transmitted by Abu Hurairah through a different chain of narrators to the same effect. This version adds:He should then prolong it afterwards as much as he likes. Abu Dawud said: This tradition has been transmitted by Hammad b. Salamah, Zuhair b. Mu'awiyah and a group of narrators from Hisham. They transmitted it as a statement of Abu Hurairah himself (mauquf). This tradition has also been transmitted by Ibn 'Awn from Muhammad (b. Sirin). This version has the wordings: These two rak'ahs were short}}
\hadithdefcmd{abudawud}{1325}{حَدَّثَنَا ابْنُ حَنْبَلٍ، - يَعْنِي أَحْمَدَ - حَدَّثَنَا حَجَّاجٌ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي عُثْمَانُ بْنُ أَبِي سُلَيْمَانَ، عَنْ عَلِيٍّ الأَزْدِيِّ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ حُبْشِيٍّ الْخَثْعَمِيِّ، ‏:‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ أَىُّ الأَعْمَالِ أَفْضَلُ قَالَ ‏:‏ ‏ "‏ طُولُ الْقِيَامِ ‏"‏ ‏.‏\hadithno{1325}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Habashi al-Khath'ami: The Prophet (ﷺ) was asked: which is the best action? He replied: To stand in prayer for a long time}}
\hadithdefcmd{abudawud}{1326}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، وَعَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، ‏:‏ أَنَّ رَجُلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ صَلاَةِ اللَّيْلِ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ صَلاَةُ اللَّيْلِ مَثْنَى مَثْنَى، فَإِذَا خَشِيَ أَحَدُكُمُ الصُّبْحَ صَلَّى رَكْعَةً وَاحِدَةً تُوتِرُ لَهُ مَا قَدْ صَلَّى ‏"‏ ‏.‏\hadithno{1326}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (990) Sahih Muslim (749)}\hadithtrans{Narrated 'Abdullah bin 'Umar:A man asked the Messenger of Allah (ﷺ) about the prayer at night. The Messenger of Allah (ﷺ) said: Prayer during the night should consist of pairs of rak'ahs, but if one of you fears the morning is near he should pray one rak'ah which will make his prayer an odd number for him}}
\hadithdefcmd{abudawud}{1327}{حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ الْوَرْكَانِيُّ، حَدَّثَنَا ابْنُ أَبِي الزِّنَادِ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، مَوْلَى الْمُطَّلِبِ عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏:‏ كَانَتْ قِرَاءَةُ النَّبِيِّ صلى الله عليه وسلم عَلَى قَدْرِ مَا يَسْمَعُهُ مَنْ فِي الْحُجْرَةِ وَهُوَ فِي الْبَيْتِ ‏.‏\hadithno{1327}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet's (ﷺ) recitation was loud enough for one who was in the inner chamber to hear it when he was in the house}}
\hadithdefcmd{abudawud}{1328}{حَدَّثَنَا مُحَمَّدُ بْنُ بَكَّارِ بْنِ الرَّيَّانِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ عِمْرَانَ بْنِ زَائِدَةَ، عَنْ أَبِيهِ، عَنْ أَبِي خَالِدٍ الْوَالِبِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ ‏:‏ كَانَتْ قِرَاءَةُ النَّبِيِّ صلى الله عليه وسلم بِاللَّيْلِ يَرْفَعُ طَوْرًا وَيَخْفِضُ طَوْرًا ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ أَبُو خَالِدٍ الْوَالِبِيُّ اسْمُهُ هُرْمُزُ ‏.‏\hadithno{1328}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah: The Prophet's (ﷺ) recitation at night was partly in a loud voice and partly in a low voice. Abu Dawud said: The name of Abu Khalid al-Walibi is Hurmuz}}
\hadithdefcmd{abudawud}{1329}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح وَحَدَّثَنَا الْحَسَنُ بْنُ الصَّبَّاحِ، حَدَّثَنَا يَحْيَى بْنُ إِسْحَاقَ، أَخْبَرَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي رَبَاحٍ، عَنْ أَبِي قَتَادَةَ، ‏:‏ أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ لَيْلَةً فَإِذَا هُوَ بِأَبِي بَكْرٍ - رضى الله عنه - يُصَلِّي يَخْفِضُ مِنْ صَوْتِهِ - قَالَ - وَمَرَّ بِعُمَرَ بْنِ الْخَطَّابِ وَهُوَ يُصَلِّي رَافِعًا صَوْتَهُ - قَالَ - فَلَمَّا اجْتَمَعَا عِنْدَ النَّبِيِّ صلى الله عليه وسلم قَالَ النَّبِيُّ صلى الله عليه وسلم ‏:‏ ‏"‏ يَا أَبَا بَكْرٍ مَرَرْتُ بِكَ وَأَنْتَ تُصَلِّي تَخْفِضُ صَوْتَكَ ‏"‏ ‏.‏ قَالَ ‏:‏ قَدْ أَسْمَعْتُ مَنْ نَاجَيْتُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ وَقَالَ لِعُمَرَ ‏:‏ ‏"‏ مَرَرْتُ بِكَ وَأَنْتَ تُصَلِّي رَافِعًا صَوْتَكَ ‏"‏ ‏.‏ قَالَ فَقَالَ ‏:‏ يَا رَسُولَ اللَّهِ أُوقِظُ الْوَسْنَانَ وَأَطْرُدُ الشَّيْطَانَ ‏.‏ زَادَ الْحَسَنُ فِي حَدِيثِهِ ‏:‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏:‏ ‏"‏ يَا أَبَا بَكْرٍ ارْفَعْ مِنْ صَوْتِكَ شَيْئًا ‏"‏ ‏.‏ وَقَالَ لِعُمَرَ ‏:‏ ‏"‏ اخْفِضْ مِنْ صَوْتِكَ شَيْئًا ‏"‏ ‏.‏\hadithno{1329}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuQatadah: The Prophet (ﷺ) went out at night and found AbuBakr praying in a low voice, and he passed Umar ibn al-Khattab who was raising his voice while praying. When they both met the Prophet (ﷺ) together, the Prophet (ﷺ) said: I passed by you, AbuBakr, when you were praying in a low voice. He replied: I made Him hear with Whom I was holding intimate converse, Messenger of Allah. He (the Prophet) said to Umar: I passed by you when you were praying in a loud voice. He replied: Messenger of Allah, I was awakening the drowsy and driving away the Devil. Al-Hasan added in his version: The Prophet (ﷺ) said: Raise your voice a little, AbuBakr, and he said to Umar: Lower your voice a little}}
\hadithdefcmd{abudawud}{1330}{حَدَّثَنَا أَبُو حَصِينِ بْنُ يَحْيَى الرَّازِيُّ، حَدَّثَنَا أَسْبَاطُ بْنُ مُحَمَّدٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذِهِ الْقِصَّةِ لَمْ يَذْكُرْ فَقَالَ لأَبِي بَكْرٍ ‏:‏ ‏"‏ ارْفَعْ مِنْ صَوْتِكَ شَيْئًا ‏"‏ ‏.‏ وَلِعُمَرَ ‏:‏ ‏"‏ اخْفِضْ شَيْئًا ‏"‏ ‏.‏ زَادَ ‏:‏ ‏"‏ وَقَدْ سَمِعْتُكَ يَا بِلاَلُ وَأَنْتَ تَقْرَأُ مِنْ هَذِهِ السُّورَةِ وَمِنْ هَذِهِ السُّورَةِ ‏"‏ ‏.‏ قَالَ ‏:‏ كَلاَمٌ طَيِّبٌ يَجْمَعُ اللَّهُ تَعَالَى بَعْضَهُ إِلَى بَعْضٍ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏:‏ ‏"‏ كُلُّكُمْ قَدْ أَصَابَ ‏"‏ ‏.‏\hadithno{1330}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{This tradition has also been transmitted by Abu Hurairah through a different chain of narrators. This version dies not mention that the Prophet (ﷺ) said to Abu Bakr:Raise your voice a litte ; or he said to 'Umar: Lower your voice a little. But this version adds: (The Prophet said:) I heard you, Bilal, (reciting) ; you were reciting partly from this surah and partly from that surah. He said: This is all good speech ; Allah has combined one part with the other; The Prophet (ﷺ) said: All of you were correct}}
\hadithdefcmd{abudawud}{1331}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رضى الله عنها ‏:‏ أَنَّ رَجُلاً، قَامَ مِنَ اللَّيْلِ فَقَرَأَ فَرَفَعَ صَوْتَهُ بِالْقُرْآنِ، فَلَمَّا أَصْبَحَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏"‏ يَرْحَمُ اللَّهُ فُلاَنًا، كَأَيِّنْ مِنْ آيَةٍ أَذْكَرَنِيهَا اللَّيْلَةَ كُنْتُ قَدْ أَسْقَطْتُهَا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ رَوَاهُ هَارُونُ النَّحْوِيُّ عَنْ حَمَّادِ بْنِ سَلَمَةَ فِي سُورَةِ آلِ عِمْرَانَ فِي الْحُرُوفِ ‏\{‏ وَكَأَيِّنْ مِنْ نَبِيٍّ ‏\}‏ ‏.‏\hadithno{1331}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Aishah: A man got up at night and recited the Qur'an in a loud voice. When the dawn came, the Messenger of Allah (ﷺ) said: May Allah have mercy on so-and-so who reminded me many verses that I had nearly forgotten. Abu Dawud said: Harun al-Nahwi transmitted from Hammad b. Salamah the Quranic verse of Surah Al-'Imran: "How many of the prophet fought (in Allah's way)" (3:)}}
\hadithdefcmd{abudawud}{1332}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ ‏:‏ اعْتَكَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْمَسْجِدِ فَسَمِعَهُمْ يَجْهَرُونَ بِالْقِرَاءَةِ، فَكَشَفَ السِّتْرَ وَقَالَ ‏:‏ ‏"‏ أَلاَ إِنَّ كُلَّكُمْ مُنَاجٍ رَبَّهُ فَلاَ يُؤْذِيَنَّ بَعْضُكُمْ بَعْضًا، وَلاَ يَرْفَعْ بَعْضُكُمْ عَلَى بَعْضٍ فِي الْقِرَاءَةِ ‏"‏ ‏.‏ أَوْ قَالَ ‏:‏ ‏"‏ فِي الصَّلاَةِ ‏"‏ ‏.‏\hadithno{1332}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuSa'id al-Khudri: The Messenger of Allah (ﷺ) retired to the mosque. He heard them (the people) reciting the Qur'an in a loud voice. He removed the curtain and said: Lo! every one of you is calling his Lord quietly. One should not trouble the other and one should not raise the voice in recitation or in prayer over the voice of the other}}
\hadithdefcmd{abudawud}{1333}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ بَحِيرِ بْنِ سَعْدٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ كَثِيرِ بْنِ مُرَّةَ الْحَضْرَمِيِّ، عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ الْجَاهِرُ بِالْقُرْآنِ كَالْجَاهِرِ بِالصَّدَقَةِ، وَالْمُسِرُّ بِالْقُرْآنِ كَالْمُسِرِّ بِالصَّدَقَةِ ‏"‏ ‏.‏\hadithno{1333}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Uqbah ibn Amir al-Juhani: The Prophet (ﷺ) said: One who recites the Qur'an in a loud voice is like one who gives alms openly; and one who recites the Qur'an quietly is one who gives alms secretly}}
\hadithdefcmd{abudawud}{1334}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ حَنْظَلَةَ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ ‏:‏ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي مِنَ اللَّيْلِ عَشْرَ رَكَعَاتٍ، وَيُوتِرُ بِسَجْدَةٍ، وَيَسْجُدُ سَجْدَتَىِ الْفَجْرِ، فَذَلِكَ ثَلاَثَ عَشْرَةَ رَكْعَةً ‏.‏\hadithno{1334}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1140) Sahih Muslim (738)}\hadithtrans{Narrated 'Aishah:The Messenger of Allah (ﷺ) used to pray ten rak'ahs during the night, and would observe the witr with one rak'ah, he then prayed two rak'ahs of the dawn prayer. Thus he prayed thirteen rak'ahs in all}}
\hadithdefcmd{abudawud}{1335}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم ‏:‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي مِنَ اللَّيْلِ إِحْدَى عَشْرَةَ رَكْعَةً، يُوتِرُ مِنْهَا بِوَاحِدَةٍ، فَإِذَا فَرَغَ مِنْهَا اضْطَجَعَ عَلَى شِقِّهِ الأَيْمَنِ ‏.‏\hadithno{1335}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (736)}\hadithtrans{Narrated 'Aishah, wife of Prophet (ﷺ):The Messenger of Allah (ﷺ) used to pray eleven rak'ahs (at night, observing the witr with one rak'ahs). When he finished it (the prayer), he would lie down on his right side}}
\hadithdefcmd{abudawud}{1336}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، وَنَصْرُ بْنُ عَاصِمٍ، - وَهَذَا لَفْظُهُ - قَالاَ حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا الأَوْزَاعِيُّ، - وَقَالَ نَصْرٌ ‏:‏ عَنِ ابْنِ أَبِي ذِئْبٍ، وَالأَوْزَاعِيِّ، - عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ ‏:‏ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي فِيمَا بَيْنَ أَنْ يَفْرُغَ مِنْ صَلاَةِ الْعِشَاءِ إِلَى أَنْ يَنْصَدِعَ الْفَجْرُ إِحْدَى عَشْرَةَ رَكْعَةً، يُسَلِّمُ مِنْ كُلِّ ثِنْتَيْنِ وَيُوتِرُ بِوَاحِدَةٍ، وَيَمْكُثُ فِي سُجُودِهِ قَدْرَ مَا يَقْرَأُ أَحَدُكُمْ خَمْسِينَ آيَةً قَبْلَ أَنْ يَرْفَعَ رَأْسَهُ، فَإِذَا سَكَتَ الْمُؤَذِّنُ بِالأُولَى مِنْ صَلاَةِ الْفَجْرِ قَامَ فَرَكَعَ رَكْعَتَيْنِ خَفِيفَتَيْنِ، ثُمَّ اضْطَجَعَ عَلَى شِقِّهِ الأَيْمَنِ حَتَّى يَأْتِيَهُ الْمُؤَذِّنُ ‏.‏\hadithno{1336}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Aishah:Between the time when the Messenger of Allah (ﷺ) finished the night prayer till the dawn broke, he used to pray eleven rak'ahs, uttering the salutation at the end of every two and observing the witr with a single one, and during that he would make a prostration about as long a one of you would take to recite fifty verses before raising his head. When the mu'adhdhin finished making the call for the dawn prayer, he stood up and prayed two short rak'ahs, then he lay down on his right side till the mu'adhdhin came to him}}
\hadithdefcmd{abudawud}{1337}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي ابْنُ أَبِي ذِئْبٍ، وَعَمْرُو بْنُ الْحَارِثِ، وَيُونُسُ بْنُ يَزِيدَ، أَنَّ ابْنَ شِهَابٍ، أَخْبَرَهُمْ بِإِسْنَادِهِ، وَمَعْنَاهُ،، قَالَ ‏:‏ وَيُوتِرُ بِوَاحِدَةٍ، وَيَسْجُدُ سَجْدَةً قَدْرَ مَا يَقْرَأُ أَحَدُكُمْ خَمْسِينَ آيَةً قَبْلَ أَنْ يَرْفَعَ رَأْسَهُ، فَإِذَا سَكَتَ الْمُؤَذِّنُ مِنْ صَلاَةِ الْفَجْرِ وَتَبَيَّنَ لَهُ الْفَجْرُ ‏.‏ وَسَاقَ مَعْنَاهُ ‏.‏ قَالَ ‏:‏ وَبَعْضُهُمْ يَزِيدُ عَلَى بَعْضٍ ‏.‏\hadithno{1337}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (736)}\hadithtrans{This tradition has been transmitted by Ibn Shihab through a different chain of narrators to the same effect. This version adds:He would observe witr with a single rak'ah and make a prostration as long as you would take to recite fifty verses before raising his head. When the mu'adhdhin finished his call for the dawn prayer and the dawn became clear to him.... Then the narrator transmitted the rest of the tradition to the same effect. Some narrators added something more in their version}}
\hadithdefcmd{abudawud}{1338}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ ‏:‏ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي مِنَ اللَّيْلِ ثَلاَثَ عَشْرَةَ رَكْعَةً يُوتِرُ مِنْهَا بِخَمْسٍ، لاَ يَجْلِسُ فِي شَىْءٍ مِنَ الْخَمْسِ حَتَّى يَجْلِسَ فِي الآخِرَةِ فَيُسَلِّمَ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ رَوَاهُ ابْنُ نُمَيْرٍ عَنْ هِشَامٍ، نَحْوَهُ ‏.‏\hadithno{1338}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (737)}\hadithtrans{Narrated 'Aishah:The Messenger of Allah (ﷺ) used to pray thirteen rak'ahs during the night, observing a witr out of that with five, he did not sit during the five except the last and then gave the salutation. Abu Dawud said: Ibn Numair reported it from Hisham recently}}
\hadithdefcmd{abudawud}{1339}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ ‏:‏ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي بِاللَّيْلِ ثَلاَثَ عَشْرَةَ رَكْعَةً، ثُمَّ يُصَلِّي إِذَا سَمِعَ النِّدَاءَ بِالصُّبْحِ رَكْعَتَيْنِ خَفِيفَتَيْنِ ‏.‏\hadithno{1339}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1170)}\hadithtrans{Narrated 'Aishah:The Messenger of Allah (ﷺ) used to pray thirteen rak'ahs during the night ; he then offered two light rak'ahs of prayer when he heard the call to the dawn prayer}}
\hadithdefcmd{abudawud}{1340}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، وَمُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالاَ حَدَّثَنَا أَبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، ‏:‏ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي مِنَ اللَّيْلِ ثَلاَثَ عَشْرَةَ رَكْعَةً، وَكَانَ يُصَلِّي ثَمَانِيَ رَكَعَاتٍ، وَيُوتِرُ بِرَكْعَةٍ، ثُمَّ يُصَلِّي - قَالَ مُسْلِمٌ ‏:‏ بَعْدَ الْوِتْرِ، ثُمَّ اتَّفَقَا - رَكْعَتَيْنِ وَهُوَ قَاعِدٌ، فَإِذَا أَرَادَ أَنْ يَرْكَعَ قَامَ فَرَكَعَ، وَيُصَلِّي بَيْنَ أَذَانِ الْفَجْرِ وَالإِقَامَةِ رَكْعَتَيْنِ ‏.‏\hadithno{1340}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (738)}\hadithtrans{Narrated 'Aishah:The Prophet (ﷺ) used to pray thirteen rak'ahs during the night. He would offer eight rak'ahs observing the witr with one rak'ah. Then he prayed (the narrator Muslim said) two rak'ahs after witr prayer in sitting position. When he wished to bow, he stood up and bowed. He used to pray two rak'ahs between the call to the dawn prayer and the iqamah}}
\hadithdefcmd{abudawud}{1341}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ أَخْبَرَهُ ‏:‏ أَنَّهُ، سَأَلَ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم كَيْفَ كَانَتْ صَلاَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي رَمَضَانَ فَقَالَتْ ‏:‏ مَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَزِيدُ فِي رَمَضَانَ وَلاَ فِي غَيْرِهِ عَلَى إِحْدَى عَشْرَةَ رَكْعَةً ‏:‏ يُصَلِّي أَرْبَعًا فَلاَ تَسْأَلْ عَنْ حُسْنِهِنَّ وَطُولِهِنَّ، ثُمَّ يُصَلِّي أَرْبَعًا فَلاَ تَسْأَلْ عَنْ حُسْنِهِنَّ وَطُولِهِنَّ، ثُمَّ يُصَلِّي ثَلاَثًا، قَالَتْ عَائِشَةُ - رضى الله عنها - فَقُلْتُ ‏:‏ يَا رَسُولَ اللَّهِ أَتَنَامُ قَبْلَ أَنْ تُوتِرَ قَالَ ‏:‏ ‏ "‏ يَا عَائِشَةُ إِنَّ عَيْنَىَّ تَنَامَانِ وَلاَ يَنَامُ قَلْبِي ‏"‏ ‏.‏\hadithno{1341}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1147) Sahih Muslim (737)}\hadithtrans{Abu Salamah b. 'Abd al-Rahman asked 'Aishah, the wife of the Prophet (ﷺ):How did the Messenger of Allah (ﷺ) pray during Ramadhan ? She said: The Messenger of Allah (ﷺ) did not pray more than eleven rak'ahs during Ramadhan and other than Ramadhan. He would pray four rak'ahs. Do not ask about their elegance and length. He then would pray for rak'ahs. Do not ask about their alegance and length. Then he would pray three rak'ahs. 'Aishah said: I asked: Messenger of Allah, do you sleep before observing witr ? He replied: 'Aishah, my eyes sleep, but my heart does not sleep}}
\hadithdefcmd{abudawud}{1342}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ سَعْدِ بْنِ هِشَامٍ، قَالَ ‏:‏ طَلَّقْتُ امْرَأَتِي فَأَتَيْتُ الْمَدِينَةَ لأَبِيعَ عَقَارًا كَانَ لِي بِهَا، فَأَشْتَرِيَ بِهِ السِّلاَحَ وَأَغْزُوَ، فَلَقِيتُ نَفَرًا مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فَقَالُوا ‏:‏ قَدْ أَرَادَ نَفَرٌ مِنَّا سِتَّةٌ أَنْ يَفْعَلُوا ذَلِكَ فَنَهَاهُمُ النَّبِيُّ صلى الله عليه وسلم وَقَالَ ‏:‏ ‏"‏ لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ ‏"‏ ‏.‏ فَأَتَيْتُ ابْنَ عَبَّاسٍ فَسَأَلْتُهُ عَنْ وِتْرِ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏:‏ أَدُلُّكَ عَلَى أَعْلَمِ النَّاسِ بِوِتْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأْتِ عَائِشَةَ رضى الله عنها ‏.‏ فَأَتَيْتُهَا فَاسْتَتْبَعْتُ حَكِيمَ بْنَ أَفْلَحَ فَأَبَى فَنَاشَدْتُهُ فَانْطَلَقَ مَعِي، فَاسْتَأْذَنَّا عَلَى عَائِشَةَ، فَقَالَتْ ‏:‏ مَنْ هَذَا قَالَ ‏:‏ حَكِيمُ بْنُ أَفْلَحَ ‏.‏ قَالَتْ ‏:‏ وَمَنْ مَعَكَ قَالَ ‏:‏ سَعْدُ بْنُ هِشَامٍ ‏.‏ قَالَتْ ‏:‏ هِشَامُ بْنُ عَامِرٍ الَّذِي قُتِلَ يَوْمَ أُحُدٍ قَالَ قُلْتُ ‏:‏ نَعَمْ ‏.‏ قَالَتْ ‏:‏ نِعْمَ الْمَرْءُ كَانَ عَامِرًا ‏.‏ قَالَ قُلْتُ ‏:‏ يَا أُمَّ الْمُؤْمِنِينَ حَدِّثِينِي عَنْ خُلُقِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَتْ ‏:‏ أَلَسْتَ تَقْرَأُ الْقُرْآنَ فَإِنَّ خُلُقَ رَسُولِ اللَّهِ صلى الله عليه وسلم كَانَ الْقُرْآنَ ‏.‏ قَالَ قُلْتُ ‏:‏ حَدِّثِينِي عَنْ قِيَامِ اللَّيْلِ قَالَتْ ‏:‏ أَلَسْتَ تَقْرَأُ ‏\{‏ يَا أَيُّهَا الْمُزَّمِّلُ ‏\}‏ قَالَ قُلْتُ ‏:‏ بَلَى ‏.‏ قَالَتْ ‏:‏ فَإِنَّ أَوَّلَ هَذِهِ السُّورَةِ نَزَلَتْ، فَقَامَ أَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى انْتَفَخَتْ أَقْدَامُهُمْ، وَحُبِسَ خَاتِمَتُهَا فِي السَّمَاءِ اثْنَىْ عَشَرَ شَهْرًا، ثُمَّ نَزَلَ آخِرُهَا فَصَارَ قِيَامُ اللَّيْلِ تَطَوُّعًا بَعْدَ فَرِيضَةٍ ‏.‏ قَالَ قُلْتُ ‏:‏ حَدِّثِينِي عَنْ وِتْرِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَتْ ‏:‏ كَانَ يُوتِرُ بِثَمَانِ رَكَعَاتٍ لاَ يَجْلِسُ إِلاَّ فِي الثَّامِنَةِ، ثُمَّ يَقُومُ فَيُصَلِّي رَكْعَةً أُخْرَى، لاَ يَجْلِسُ إِلاَّ فِي الثَّامِنَةِ وَالتَّاسِعَةِ، وَلاَ يُسَلِّمُ إِلاَّ فِي التَّاسِعَةِ، ثُمَّ يُصَلِّي رَكْعَتَيْنِ وَهُوَ جَالِسٌ فَتِلْكَ إِحْدَى عَشْرَةَ رَكْعَةً يَا بُنَىَّ، فَلَمَّا أَسَنَّ وَأَخَذَ اللَّحْمَ أَوْتَرَ بِسَبْعِ رَكَعَاتٍ لَمْ يَجْلِسْ إِلاَّ فِي السَّادِسَةِ وَالسَّابِعَةِ، وَلَمْ يُسَلِّمْ إِلاَّ فِي السَّابِعَةِ، ثُمَّ يُصَلِّي رَكْعَتَيْنِ وَهُوَ جَالِسٌ، فَتِلْكَ هِيَ تِسْعُ رَكَعَاتٍ يَا بُنَىَّ، وَلَمْ يَقُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْلَةً يُتِمُّهَا إِلَى الصَّبَاحِ، وَلَمْ يَقْرَإِ الْقُرْآنَ فِي لَيْلَةٍ قَطُّ، وَلَمْ يَصُمْ شَهْرًا يُتِمُّهُ غَيْرَ رَمَضَانَ، وَكَانَ إِذَا صَلَّى صَلاَةً دَاوَمَ عَلَيْهَا، وَكَانَ إِذَا غَلَبَتْهُ عَيْنَاهُ مِنَ اللَّيْلِ بِنَوْمٍ صَلَّى مِنَ النَّهَارِ ثِنْتَىْ عَشْرَةَ رَكْعَةً ‏.‏ قَالَ ‏:‏ فَأَتَيْتُ ابْنَ عَبَّاسٍ فَحَدَّثْتُهُ ‏.‏ فَقَالَ ‏:‏ هَذَا وَاللَّهِ هُوَ الْحَدِيثُ، وَلَوْ كُنْتُ أُكَلِّمُهَا لأَتَيْتُهَا حَتَّى أُشَافِهَهَا بِهِ مُشَافَهَةً ‏.‏ قَالَ قُلْتُ ‏:‏ لَوْ عَلِمْتُ أَنَّكَ لاَ تُكَلِّمُهَا مَا حَدَّثْتُكَ ‏.‏\hadithno{1342}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (746)}\hadithtrans{Narrated Sa'd bin Hisham: I divorced my wife. I then came to Medina to sell my land that was there so that I could buy arms and fight in battle. I met a group of the Companions of the Prophet (ﷺ). They said: Six persons of us intended to do so (i.e. divorce their wives and purchase weapons), but the Prophet (ﷺ) prohibited them. He said: For you in the Messenger of Allah there is an excellent model. I then came to Ibn 'Abbas and asked him about the witr observed by the Prophet (ﷺ). He said: I point to you a person who is most familiar with the witr observed by the Messenger of Allah (ﷺ). Go to 'Aishah. While going to her I asked Hakim b. Aflah to accompany me. He refused, but I adjured him. He, therefore, went along with me. We sought permission to enter upon 'Aishah. She said: Who is this ? He said: Hakim b. Aflah. She asked: Who is with you ? He replied: Sa'd b. Hisham. She said: Hisham son of 'Amir who was killed in the Battle of Uhud. I said: Yes. She said: What a good man 'Amir was! I said: Mother of faithful, tell me about the character of the Messenger of Allah (ﷺ). She asked: Do you not recite the Quran ? The character of Messenger of Allah (ﷺ) was the Qur'an. I asked: Tell me about his vigil and prayer at night. She replied: Do you not recite: "O thou folded in garments" (73:1). I said: Why not ? When the opening of this Surah was revealed, the Companions stood praying (most of the night) until their fett swelled, and the concluding verses were not revealed for twelve months from heaven. At last the concluding verses were revealed and the prayer at night became voluntary after it was obligatory. I said: Tell me about the witr of the Prophet (ﷺ). She replied: He used to pray eight rak'ahs, sitting only during the eighth of them. Then he would stand up and pray another rak'ahs. He would sit only after the eighth and the ninth rak'ahs. He would utter salutation only after the ninth rak'ah. He would then pray two rak'ahs sitting and that made eleven rak'ahs, O my son. But when he grew old and became fleshy he observed a witr of seven, sitting only in sixth and seventh rak'ahs, and would utter salutation only after the seventh rak'ah. He would then pray two rak'ahs sitting, and that made nine rak'ahs, O my son. The Messenger of Allah (ﷺ) would not pray through a whole night, or recite the whole Qur'an in a night or fast a complete month except in Ramadan. When he offered prayer, he would do that regularly. When he was overtaken by sleep at night, he would pray twelve rak'ahs. The narrator said: I came to Ibn 'Abbas and narrated all this to him. By Allah, this is really a tradition. Has I been on speaking terms with her, I would have come to her and heard it from her mouth. I said: If I knew that you were not on speaking terms with her, I would have never narrated it to you}}
\hadithdefcmd{abudawud}{1343}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، بِإِسْنَادِهِ نَحْوَهُ قَالَ ‏:‏ يُصَلِّي ثَمَانِ رَكَعَاتٍ لاَ يَجْلِسُ فِيهِنَّ إِلاَّ عِنْدَ الثَّامِنَةِ، فَيَجْلِسُ فَيَذْكُرُ اللَّهَ عَزَّ وَجَلَّ، ثُمَّ يَدْعُو، ثُمَّ يُسَلِّمُ تَسْلِيمًا يُسْمِعُنَا، ثُمَّ يُصَلِّي رَكْعَتَيْنِ وَهُوَ جَالِسٌ بَعْدَ مَا يُسَلِّمُ، ثُمَّ يُصَلِّي رَكْعَةً، فَتِلْكَ إِحْدَى عَشْرَةَ رَكْعَةً يَا بُنَىَّ، فَلَمَّا أَسَنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَخَذَ اللَّحْمَ أَوْتَرَ بِسَبْعٍ، وَصَلَّى رَكْعَتَيْنِ وَهُوَ جَالِسٌ بَعْدَ مَا يُسَلِّمُ، بِمَعْنَاهُ إِلَى مُشَافَهَةً ‏.‏\hadithno{1343}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The above mentioned tradition has also been narrated by Qatadah through a different chain of narrators. This version adds:He (the Prophet( used to pray eight rak'ahs during which he did not sit except the eight rak'ahs. He would sit, make mention of Allah, supplicate Him and then utter the salutation so loudly that we could hear it. He would then pray two rak'ahs sitting after he had uttered the salutation. Then he would pray one rak'ah, and that made eleven rak'ahs, O my son. When the Messenger of Allah (ﷺ) grew old and became fleshy, he offered seven rak'ahs of witr, and then he would pray two rak'ahs sitting after he had uttered the salutation. The narrator narrated the tradition to the same effect till the end}}
\hadithdefcmd{abudawud}{1344}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا سَعِيدٌ، بِهَذَا الْحَدِيثِ قَالَ ‏:‏ يُسَلِّمُ تَسْلِيمًا يُسْمِعُنَا كَمَا قَالَ يَحْيَى بْنُ سَعِيدٍ ‏.‏\hadithno{1344}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The above tradition has also been transmitted by Yahya b. Sa'id to the same effect. The version adds the words:"He uttered the salutation so loudly that we could hear it}}
\hadithdefcmd{abudawud}{1345}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، بِهَذَا الْحَدِيثِ قَالَ ابْنُ بَشَّارٍ بِنَحْوِ حَدِيثِ يَحْيَى بْنِ سَعِيدٍ إِلاَّ أَنَّهُ قَالَ ‏:‏ وَيُسَلِّمُ تَسْلِيمَةً يُسْمِعُنَا ‏.‏\hadithno{1345}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{This tradition has also been transmitted by Sa'id through a different chain of narrators to the same effect. Ibn Bashshar narrated the tradition like that of Yahya b. Sa'id. His version has:He uttered the salutation in a way that we could hear it}}
\hadithdefcmd{abudawud}{1346}{حَدَّثَنَا عَلِيُّ بْنُ حُسَيْنٍ الدِّرْهَمِيُّ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ بَهْزِ بْنِ حَكِيمٍ، حَدَّثَنَا زُرَارَةُ بْنُ أَوْفَى، ‏:‏ أَنَّ عَائِشَةَ، - رضى الله عنها - سُئِلَتْ عَنْ صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي جَوْفِ اللَّيْلِ، فَقَالَتْ ‏:‏ كَانَ يُصَلِّي صَلاَةَ الْعِشَاءِ فِي جَمَاعَةٍ، ثُمَّ يَرْجِعُ إِلَى أَهْلِهِ فَيَرْكَعُ أَرْبَعَ رَكَعَاتٍ، ثُمَّ يَأْوِي إِلَى فِرَاشِهِ وَيَنَامُ وَطَهُورُهُ مُغَطًّى عِنْدَ رَأْسِهِ، وَسِوَاكُهُ مَوْضُوعٌ حَتَّى يَبْعَثَهُ اللَّهُ سَاعَتَهُ الَّتِي يَبْعَثُهُ مِنَ اللَّيْلِ، فَيَتَسَوَّكُ وَيُسْبِغُ الْوُضُوءَ، ثُمَّ يَقُومُ إِلَى مُصَلاَّهُ فَيُصَلِّي ثَمَانِ رَكَعَاتٍ يَقْرَأُ فِيهِنَّ بِأُمِّ الْكِتَابِ وَسُورَةٍ مِنَ الْقُرْآنِ وَمَا شَاءَ اللَّهُ، وَلاَ يَقْعُدُ فِي شَىْءٍ مِنْهَا حَتَّى يَقْعُدَ فِي الثَّامِنَةِ، وَلاَ يُسَلِّمُ، وَيَقْرَأُ فِي التَّاسِعَةِ، ثُمَّ يَقْعُدُ فَيَدْعُو بِمَا شَاءَ اللَّهُ أَنْ يَدْعُوَهُ، وَيَسْأَلُهُ وَيَرْغَبُ إِلَيْهِ وَيُسَلِّمُ تَسْلِيمَةً وَاحِدَةً شَدِيدَةً، يَكَادُ يُوقِظُ أَهْلَ الْبَيْتِ مِنْ شِدَّةِ تَسْلِيمِهِ، ثُمَّ يَقْرَأُ وَهُوَ قَاعِدٌ بِأُمِّ الْكِتَابِ، وَيَرْكَعُ وَهُوَ قَاعِدٌ، ثُمَّ يَقْرَأُ الثَّانِيَةَ فَيَرْكَعُ وَيَسْجُدُ وَهُوَ قَاعِدٌ، ثُمَّ يَدْعُو مَا شَاءَ اللَّهُ أَنْ يَدْعُوَ، ثُمَّ يُسَلِّمُ وَيَنْصَرِفُ، فَلَمْ تَزَلْ تِلْكَ صَلاَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى بَدَّنَ فَنَقَصَ مِنَ التِّسْعِ ثِنْتَيْنِ، فَجَعَلَهَا إِلَى السِّتِّ وَالسَّبْعِ وَرَكْعَتَيْهِ وَهُوَ قَاعِدٌ حَتَّى قُبِضَ عَلَى ذَلِكَ صلى الله عليه وسلم ‏.‏\hadithno{1346}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Zurarah ibn Awfa said that Aisha was asked about the midnight prayer of the Messenger of Allah (ﷺ). She said: He used to offer his night prayer in congregation and then return to his family (in his house) and pray four rak'ahs. Then he would go to his bed and sleep, but the water for his ablution was placed covered near his head and his tooth-stick was also kept there until Allah awakened him at night. He then used the tooth-stick, performed ablution perfectly then came to the place of prayer and would pray eight rak'ahs, in which he would recite Surah al-Fatihah, and a surah from the Qur'an as Allah willed. He would not sit during any of them but sit after the eighth rak'ah, and would not utter the salutation, but recite (the Qur'an) during the ninth rak'ah. Then he would sit and supplicate as long as Allah willed, and beg Him and devote his attention to Him; He would utter the salutation once in such a loud voice that the inmates of the house were almost awakened by his loud salutation. He would then recite Surah al-Fatihah while sitting, bow while sitting, and then recite the Qur'an during the second rak'ah, and would bow and prostrate while sitting. He would supplicate Allah as long as He willed, then utter the salutation and turn away. This amount of prayer of the Messenger of Allah (ﷺ) continued till he put a weight. During that period he retrenched two rak'ahs from nine and began to pray six and seven rak'ahs standing and two rak'ahs sitting. This continued till he died}}
\hadithdefcmd{abudawud}{1347}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا بَهْزُ بْنُ حَكِيمٍ، فَذَكَرَ هَذَا الْحَدِيثَ بِإِسْنَادِهِ قَالَ ‏:‏ يُصَلِّي الْعِشَاءَ ثُمَّ يَأْوِي إِلَى فِرَاشِهِ، لَمْ يَذْكُرِ الأَرْبَعَ رَكَعَاتٍ، وَسَاقَ الْحَدِيثَ قَالَ فِيهِ ‏:‏ فَيُصَلِّي ثَمَانِيَ رَكَعَاتٍ يُسَوِّي بَيْنَهُنَّ فِي الْقِرَاءَةِ وَالرُّكُوعِ وَالسُّجُودِ، وَلاَ يَجْلِسُ فِي شَىْءٍ مِنْهُنَّ إِلاَّ فِي الثَّامِنَةِ، فَإِنَّهُ كَانَ يَجْلِسُ ثُمَّ يَقُومُ وَلاَ يُسَلِّمُ، فَيُصَلِّي رَكْعَةً يُوتِرُ بِهَا، ثُمَّ يُسَلِّمُ تَسْلِيمَةً يَرْفَعُ بِهَا صَوْتَهُ حَتَّى يُوقِظَنَا، ثُمَّ سَاقَ مَعْنَاهُ ‏.‏\hadithno{1347}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The above-mentioned tradition has also been narrated by Banu al-Hakim through a different chain of narrators. This version adds:He (the Prophet) would offer the night prayer and go to his bed. In this version there is no mention of praying four rak'ahs. The narrator then transmitted the rest of the tradition. This version further says: He would pray eight rak'ahs during which his recitation of the Qur'an, bowing and prostration were all equal. He would sit only after the eight rak'ah, and then stand up without uttering the salutation, and pray one rak'ah observing witr prayer and then give the salutation raising his voice so much so that we were about to awake. The narrator then transmitted the tradition to the same effect}}
\hadithdefcmd{abudawud}{1348}{حَدَّثَنَا عُمَرُ بْنُ عُثْمَانَ، حَدَّثَنَا مَرْوَانُ، - يَعْنِي ابْنَ مُعَاوِيَةَ - عَنْ بَهْزٍ، حَدَّثَنَا زُرَارَةُ بْنُ أَوْفَى، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، ‏:‏ أَنَّهَا سُئِلَتْ عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ ‏:‏ كَانَ يُصَلِّي بِالنَّاسِ الْعِشَاءَ، ثُمَّ يَرْجِعُ إِلَى أَهْلِهِ فَيُصَلِّي أَرْبَعًا، ثُمَّ يَأْوِي إِلَى فِرَاشِهِ، ثُمَّ سَاقَ الْحَدِيثَ بِطُولِهِ وَلَمْ يَذْكُرْ ‏:‏ يُسَوِّي بَيْنَهُنَّ فِي الْقِرَاءَةِ وَالرُّكُوعِ وَالسُّجُودِ ‏.‏ وَلَمْ يَذْكُرْ فِي التَّسْلِيمِ ‏:‏ حَتَّى يُوقِظَنَا ‏.‏\hadithno{1348}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Zurarah b. Awfa said that 'Aishah was asked about the prayer of the Messenger of Allah (ﷺ). She said:He used to lead the people in the 'Isha prayer and return to his family and pray four rak'ahs and go to his bed. The narrator then transmitted the tradition in full. This version does not mention the words: "During them (the rak'ahs) he equated all the recitation of the Qur'an, bowing and recitation." This also does not mention the words about the salutation: "Till he almost awakened us}}
\hadithdefcmd{abudawud}{1349}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ سَلَمَةَ - عَنْ بَهْزِ بْنِ حَكِيمٍ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، - رضى الله عنها - بِهَذَا الْحَدِيثِ وَلَيْسَ فِي تَمَامِ حَدِيثِهِمْ ‏.‏\hadithno{1349}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{This tradition has also been transmitted by 'Aishah through a different chain of narrators. But the tradition narrated by Hammad b. Salamah is not equal to the tradition narrated by others}}
\hadithdefcmd{abudawud}{1350}{حَدَّثَنَا مُوسَى، - يَعْنِي ابْنَ إِسْمَاعِيلَ - حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ سَلَمَةَ - عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، رضى الله عنها ‏:‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي مِنَ اللَّيْلِ ثَلاَثَ عَشْرَةَ رَكْعَةً يُوتِرُ بِسَبْعٍ أَوْ كَمَا قَالَتْ، وَيُصَلِّي رَكْعَتَيْنِ وَهُوَ جَالِسٌ، وَرَكْعَتَىِ الْفَجْرِ بَيْنَ الأَذَانِ وَالإِقَامَةِ ‏.‏\hadithno{1350}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Aishah:The Messenger of Allah (ﷺ) used to pray thirteen rak'ahs during the night, observing the witr prayer with nine (or as she said). He used to pray two rak'ahs while sitting and pray two rak'ahs of the dawn prayer between the adhan and the iqamah}}
\hadithdefcmd{abudawud}{1351}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ بْنِ وَقَّاصٍ، عَنْ عَائِشَةَ، رضى الله عنها ‏:‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُوتِرُ بِتِسْعِ رَكَعَاتٍ، ثُمَّ أَوْتَرَ بِسَبْعِ رَكَعَاتٍ، وَرَكَعَ رَكْعَتَيْنِ وَهُوَ جَالِسٌ بَعْدَ الْوِتْرِ يَقْرَأُ فِيهِمَا، فَإِذَا أَرَادَ أَنْ يَرْكَعَ قَامَ فَرَكَعَ ثُمَّ سَجَدَ، قَالَ أَبُو دَاوُدَ ‏:‏ رَوَى هَذَيْنِ الْحَدِيثَيْنِ خَالِدُ بْنُ عَبْدِ اللَّهِ الْوَاسِطِيُّ عَنْ مُحَمَّدِ بْنِ عَمْرٍو مِثْلَهُ، قَالَ فِيهِ قَالَ عَلْقَمَةُ بْنُ وَقَّاصٍ ‏:‏ يَا أُمَّتَاهُ كَيْفَ كَانَ يُصَلِّي الرَّكْعَتَيْنِ فَذَكَرَ مَعْنَاهُ ‏.‏ حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ عَنْ خَالِدٍ ‏.‏\hadithno{1351}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih Muslim (731)}\hadithtrans{Narrated 'Aishah: The Messenger of Allah (ﷺ) used to observe the witr prayer with nine rak'ahs. Then he used to pray seven rak'ahs (of witr prayer). He would pray two rak'ahs sitting after the witr in which he would recite the Qur'an (sitting). When he wished to bow, he stood up and bowed and prostrated. Abu Dawud said: These two traditions have been transmitted by Khalid b. 'Abd Allah al-Wasiti. In his version he said: 'Alqamah b. Waqqas said: O mother, how did he pray the two rak'ahs ? He narrated the rest of the tradition to the same effect}}
\hadithdefcmd{abudawud}{1352}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا هِشَامٌ، عَنِ الْحَسَنِ، عَنْ سَعْدِ بْنِ هِشَامٍ، قَالَ ‏:‏ قَدِمْتُ الْمَدِينَةَ فَدَخَلْتُ عَلَى عَائِشَةَ فَقُلْتُ ‏:‏ أَخْبِرِينِي عَنْ صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَتْ ‏:‏ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي بِالنَّاسِ صَلاَةَ الْعِشَاءِ، ثُمَّ يَأْوِي إِلَى فِرَاشِهِ فَيَنَامُ، فَإِذَا كَانَ جَوْفُ اللَّيْلِ قَامَ إِلَى حَاجَتِهِ وَإِلَى طَهُورِهِ فَتَوَضَّأَ، ثُمَّ دَخَلَ الْمَسْجِدَ فَصَلَّى ثَمَانِ رَكَعَاتٍ يُخَيَّلُ إِلَىَّ أَنَّهُ يُسَوِّي بَيْنَهُنَّ فِي الْقِرَاءَةِ وَالرُّكُوعِ وَالسُّجُودِ، ثُمَّ يُوتِرُ بِرَكْعَةٍ، ثُمَّ يُصَلِّي رَكْعَتَيْنِ وَهُوَ جَالِسٌ، ثُمَّ يَضَعُ جَنْبَهُ، فَرُبَّمَا جَاءَ بِلاَلٌ فَآذَنَهُ بِالصَّلاَةِ، ثُمَّ يُغْفِي، وَرُبَّمَا شَكَكْتُ أَغَفَى أَوْ لاَ، حَتَّى يُؤْذِنَهُ بِالصَّلاَةِ، فَكَانَتْ تِلْكَ صَلاَتَهُ حَتَّى أَسَنَّ وَلَحُمَ، فَذَكَرَتْ مِنْ لَحْمِهِ مَا شَاءَ اللَّهُ، وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{1352}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Sa'd ibn Hisham said: I came to Medina and called upon Aisha, and said to her: Tell me about the prayer of the Messenger of Allah (ﷺ). She said: The Messenger of Allah (ﷺ) used to lead the people in the night prayer, and then go to his bed and sleep. When midnight came he got up, went to answer the call of nature and to perform ablution with water. Having performed ablution, he entered the mosque and prayed eight rak'ahs. To my mind he performed the recitation of the Qur'an, bowing and prostrating equally. He then observed witr with one rak'ah and prayed two rak'ahs sitting. Then he lay down on the ground. Sometimes Bilal came to him and called him for prayer. He then dozed, and sometimes I doubted whether he dozed or not, till he (Bilal) called him for prayer. This is the prayer he offered till he grew old or put on weight. She then mentioned how he put on weight as Allah wished}}
\hadithdefcmd{abudawud}{1353}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا حُصَيْنٌ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ حُصَيْنٍ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ مُحَمَّدِ بْنِ عَلِيِّ بْنِ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، ‏:‏ أَنَّهُ رَقَدَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَرَآهُ اسْتَيْقَظَ فَتَسَوَّكَ وَتَوَضَّأَ وَهُوَ يَقُولُ ‏:‏ ‏\{‏ إِنَّ فِي خَلْقِ السَّمَوَاتِ وَالأَرْضِ ‏\}‏ حَتَّى خَتَمَ السُّورَةَ، ثُمَّ قَامَ فَصَلَّى رَكْعَتَيْنِ أَطَالَ فِيهِمَا الْقِيَامَ وَالرُّكُوعَ وَالسُّجُودَ، ثُمَّ إِنَّهُ انْصَرَفَ فَنَامَ حَتَّى نَفَخَ، ثُمَّ فَعَلَ ذَلِكَ ثَلاَثَ مَرَّاتٍ بِسِتِّ رَكَعَاتٍ، كُلُّ ذَلِكَ يَسْتَاكُ ثُمَّ يَتَوَضَّأُ وَيَقْرَأُ هَؤُلاَءِ الآيَاتِ، ثُمَّ أَوْتَرَ - قَالَ عُثْمَانُ ‏:‏ بِثَلاَثِ رَكَعَاتٍ، فَأَتَاهُ الْمُؤَذِّنُ فَخَرَجَ إِلَى الصَّلاَةِ - وَقَالَ ابْنُ عِيسَى ‏:‏ ثُمَّ أَوْتَرَ فَأَتَاهُ بِلاَلٌ فَآذَنَهُ بِالصَّلاَةِ حِينَ طَلَعَ الْفَجْرُ، فَصَلَّى رَكْعَتَىِ الْفَجْرِ ثُمَّ خَرَجَ إِلَى الصَّلاَةِ - ثُمَّ اتَّفَقَا - وَهُوَ يَقُولُ ‏:‏ ‏"‏ اللَّهُمَّ اجْعَلْ فِي قَلْبِي نُورًا، وَاجْعَلْ فِي لِسَانِي نُورًا، وَاجْعَلْ فِي سَمْعِي نُورًا، وَاجْعَلْ فِي بَصَرِي نُورًا، وَاجْعَلْ خَلْفِي نُورًا، وَأَمَامِي نُورًا، وَاجْعَلْ مِنْ فَوْقِي نُورًا، وَمِنْ تَحْتِي نُورًا، اللَّهُمَّ وَأَعْظِمْ لِي نُورًا ‏"‏ ‏.‏\hadithno{1353}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abd Allah b. 'Abbas said that he slept with the Prophet (ﷺ). He saw that he (the Prophet) awoke, used tooth-stick, performed ablution, and recited:"In the creation of the heavens and earth" [3:190] to the end of the surah. Then he stood up and prayed two rak'ahs in which he prolonged the standing, bowing, and prostrations. He then uttered turned away and slept till he bagan to snore. This he did three times. This made six rak'ahs in all. He would use tooth-stick, then perform ablution, and recite those verses. He then observed the witr prayer. The version of 'Uthman has: with three rak'ahs. The mu'adhdhin then came to him and he went out for prayer. The version of Ibn 'Isa adds: He then observed witr prayer ; then Bilal came to him and called him for prayer when the dawn broke. He then prayed the two rak'ahs of the dawn prayer. He then went out for prayer. Then both the narrators were agreed: He beagan to supplicate saying: O Allah, place light in my heart, light in my tongue, light in my hearing, light in my eyesight, light on my right hand, light on my left hand, light in front of me, light behing me, light below me, O Allah, give me abundant light}}
\hadithdefcmd{abudawud}{1354}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، عَنْ خَالِدٍ، عَنْ حُصَيْنٍ، نَحْوَهُ قَالَ ‏:‏ ‏ "‏ وَأَعْظِمْ لِي نُورًا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ وَكَذَلِكَ قَالَ أَبُو خَالِدٍ الدَّالاَنِيُّ عَنْ حَبِيبٍ فِي هَذَا، وَكَذَلِكَ قَالَ فِي هَذَا الْحَدِيثِ وَقَالَ سَلَمَةُ بْنُ كُهَيْلٍ عَنْ أَبِي رِشْدِينَ عَنِ ابْنِ عَبَّاسٍ ‏.‏\hadithno{1354}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The above tradition has also been transmitted by Husain through a different chain of narrators in like manner. This version has the words:"And give me abundant light." Abu Dawud said: This tradition has been transmitted by Abu Khalid al-Dalani from Habib and Salamah b. Kuhail from Abu Rishdin from Ibn 'Abbas in a similar manner}}
\hadithdefcmd{abudawud}{1355}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ، عَنْ شَرِيكِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي نَمِرٍ، عَنْ كُرَيْبٍ، عَنِ الْفَضْلِ بْنِ عَبَّاسٍ، قَالَ ‏:‏ بِتُّ لَيْلَةً عِنْدَ النَّبِيِّ صلى الله عليه وسلم لأَنْظُرَ كَيْفَ يُصَلِّي فَقَامَ فَتَوَضَّأَ ثُمَّ صَلَّى رَكْعَتَيْنِ قِيَامُهُ مِثْلُ رُكُوعِهِ، وَرُكُوعُهُ مِثْلُ سُجُودِهِ، ثُمَّ نَامَ، ثُمَّ اسْتَيْقَظَ فَتَوَضَّأَ وَاسْتَنَّ ثُمَّ قَرَأَ بِخَمْسِ آيَاتٍ مِنْ آلِ عِمْرَانَ ‏\{‏ إِنَّ فِي خَلْقِ السَّمَوَاتِ وَالأَرْضِ وَاخْتِلاَفِ اللَّيْلِ وَالنَّهَارِ ‏\}‏ فَلَمْ يَزَلْ يَفْعَلُ هَذَا حَتَّى صَلَّى عَشْرَ رَكَعَاتٍ، ثُمَّ قَامَ فَصَلَّى سَجْدَةً وَاحِدَةً فَأَوْتَرَ بِهَا، وَنَادَى الْمُنَادِي عِنْدَ ذَلِكَ، فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْدَ مَا سَكَتَ الْمُؤَذِّنُ فَصَلَّى سَجْدَتَيْنِ خَفِيفَتَيْنِ، ثُمَّ جَلَسَ حَتَّى صَلَّى الصُّبْحَ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ خَفِيَ عَلَىَّ مِنِ ابْنِ بَشَّارٍ بَعْضُهُ ‏.‏\hadithno{1355}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Fadl b. 'Abbas: I spent a night with the Prophet (ﷺ) to see how he prayed. He got up, performed ablution and prayed two rak'ahs. His standing was like his bowing (i.e. equal in duration), and his bowing was like his prostration (equal in length). Then he slept. Afterwards he awoke, performed ablution, and used tooth-stick. He then recited five verses from Surah Al-'Imran : "In the creation of the heavens and the earth and the alternation of night and day". He went on doing so till he prayed ten rak'ahs. He then stood up and prayed one rak'ah observing witr with it. In the meantime the mu'adhdhin called to prayer. The Messenger of Allah (ﷺ) stood up after the mu'adhdhin had kept silent. He prayed two light rak'ahs and remained sitting till he offered the dawn prayer. Abu Dawud said: A part of the tradition transmitted by Ibn Bashshar remained hidden from me}}
\hadithdefcmd{abudawud}{1356}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا مُحَمَّدُ بْنُ قَيْسٍ الأَسَدِيُّ، عَنِ الْحَكَمِ بْنِ عُتَيْبَةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏:‏ بِتُّ عِنْدَ خَالَتِي مَيْمُونَةَ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْدَ مَا أَمْسَى فَقَالَ ‏:‏ ‏ "‏ أَصَلَّى الْغُلاَمُ ‏"‏ ‏.‏ قَالُوا ‏:‏ نَعَمْ ‏.‏ فَاضْطَجَعَ حَتَّى إِذَا مَضَى مِنَ اللَّيْلِ مَا شَاءَ اللَّهُ قَامَ فَتَوَضَّأَ، ثُمَّ صَلَّى سَبْعًا أَوْ خَمْسًا أَوْتَرَ بِهِنَّ لَمْ يُسَلِّمْ إِلاَّ فِي آخِرِهِنَّ ‏.‏\hadithno{1356}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (117)}\hadithtrans{Narrated Ibn 'Abbas:I spent a night with my maternal aunt Maimunah. The Messenger of Allah (ﷺ) came after the evening has come. He asked: Did the boy pray ? She said: Yes. Then he lay down till a part of night had passed as much as Allah willed; he got up, performed ablution and prayed seven or five rak'ahs, observing witr with them. He uttered the salutation only in the last of them}}
\hadithdefcmd{abudawud}{1357}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏:‏ بِتُّ فِي بَيْتِ خَالَتِي مَيْمُونَةَ بِنْتِ الْحَارِثِ فَصَلَّى النَّبِيُّ صلى الله عليه وسلم الْعِشَاءَ، ثُمَّ جَاءَ فَصَلَّى أَرْبَعًا، ثُمَّ نَامَ، ثُمَّ قَامَ يُصَلِّي، فَقُمْتُ عَنْ يَسَارِهِ فَأَدَارَنِي فَأَقَامَنِي عَنْ يَمِينِهِ فَصَلَّى خَمْسًا ثُمَّ نَامَ حَتَّى سَمِعْتُ غَطِيطَهُ - أَوْ خَطِيطَهُ - ثُمَّ قَامَ فَصَلَّى رَكْعَتَيْنِ، ثُمَّ خَرَجَ فَصَلَّى الْغَدَاةَ ‏.‏\hadithno{1357}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (117)}\hadithtrans{Narrated Ibn 'Abbas:I spent a night in the house of my maternal aunt Maimunah, daughter of al-Harith. The Prophet (ﷺ) offered the night prayer. He then came and prayed four rak'ahs and slept. He then stood up and prayed. I stood at his left side. He made me go round and made me stand at his right side. He then prayed five rak'ahs and slept, and I heard his snoring. He then got up and prayed two rak'ahs. Afterwards he came out and offered the dawn prayer}}
\hadithdefcmd{abudawud}{1358}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عَبْدِ الْمَجِيدِ، عَنْ يَحْيَى بْنِ عَبَّادٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، أَنَّ ابْنَ عَبَّاسٍ، حَدَّثَهُ فِي، هَذِهِ الْقِصَّةِ قَالَ ‏:‏ فَقَامَ فَصَلَّى رَكْعَتَيْنِ رَكْعَتَيْنِ، حَتَّى صَلَّى ثَمَانِيَ رَكَعَاتٍ، ثُمَّ أَوْتَرَ بِخَمْسٍ لَمْ يَجْلِسْ بَيْنَهُنَّ ‏.‏\hadithno{1358}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Sa'id b. Jubair said that Ibn 'Abbas told him:He (the Prophet) got up and prayed eight rak'ahs in pairs, and then observed witr with five rak'ahs and he did not sit between them}}
\hadithdefcmd{abudawud}{1359}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ يَحْيَى الْحَرَّانِيُّ، حَدَّثَنِي مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ جَعْفَرِ بْنِ الزُّبَيْرِ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ ‏:‏ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي ثَلاَثَ عَشْرَةَ رَكْعَةً بِرَكْعَتَيْهِ قَبْلَ الصُّبْحِ ‏:‏ يُصَلِّي سِتًّا مَثْنَى مَثْنَى، وَيُوتِرُ بِخَمْسٍ لاَ يَقْعُدُ بَيْنَهُنَّ إِلاَّ فِي آخِرِهِنَّ ‏.‏\hadithno{1359}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Aishah:The Messenger of Allah (ﷺ) used to pray thirteen rak'ahs, observing six rak'ahs in pairs including the two rak'ahs of dawn prayer. He would observe witr and five rak'ahs. He sat only in the last of them}}
\hadithdefcmd{abudawud}{1360}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا أَخْبَرَتْهُ ‏:‏ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُصَلِّي بِاللَّيْلِ ثَلاَثَ عَشْرَةَ رَكْعَةً بِرَكْعَتَىِ الْفَجْرِ ‏.‏\hadithno{1360}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (737)}\hadithtrans{Narrated 'Aishah:The Prophet (ﷺ) used to pray thirteen rak'ahs during the night including the two rak'ahs of the dawn prayer}}
\hadithdefcmd{abudawud}{1361}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، وَجَعْفَرُ بْنُ مُسَافِرٍ، أَنَّ عَبْدَ اللَّهِ بْنَ يَزِيدَ الْمُقْرِئَ، أَخْبَرَهُمَا عَنْ سَعِيدِ بْنِ أَبِي أَيُّوبَ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، ‏:‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى الْعِشَاءَ، ثُمَّ صَلَّى ثَمَانِيَ رَكَعَاتٍ قَائِمًا، وَرَكْعَتَيْنِ بَيْنَ الأَذَانَيْنِ وَلَمْ يَكُنْ يَدَعُهُمَا ‏.‏ قَالَ جَعْفَرُ بْنُ مُسَافِرٍ فِي حَدِيثِهِ ‏:‏ وَرَكْعَتَيْنِ جَالِسًا بَيْنَ الأَذَانَيْنِ، زَادَ ‏:‏ جَالِسًا ‏.‏\hadithno{1361}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1159)}\hadithtrans{Narrated 'Aishah: The Messenger of Allah (ﷺ) offered the night prayer and then prayed eight rak'ahs standing, and two rak'ahs between the two adhans (i.e. the adhan for the dawn prayer and the iqamah). He never left them. Jaf'ar b. Musafir said in his version: (He prayed) the two rak'ahs sitting between the two adhans. He added the word "sitting}}
\hadithdefcmd{abudawud}{1362}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، وَمُحَمَّدُ بْنُ سَلَمَةَ الْمُرَادِيُّ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَيْسٍ، قَالَ قُلْتُ لِعَائِشَةَ رضى الله عنها ‏:‏ بِكَمْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُوتِرُ قَالَتْ ‏:‏ كَانَ يُوتِرُ بِأَرْبَعٍ وَثَلاَثٍ، وَسِتٍّ وَثَلاَثٍ، وَثَمَانٍ وَثَلاَثٍ، وَعَشْرٍ وَثَلاَثٍ، وَلَمْ يَكُنْ يُوتِرُ بِأَنْقَصَ مِنْ سَبْعٍ، وَلاَ بِأَكْثَرَ مِنْ ثَلاَثَ عَشْرَةَ ‏.‏ قَالَ أَبُو دَاوُدَ زَادَ أَحْمَدُ بْنُ صَالِحٍ ‏:‏ وَلَمْ يَكُنْ يُوتِرُ بِرَكْعَتَيْنِ قَبْلَ الْفَجْرِ ‏.‏ قُلْتُ ‏:‏ مَا يُوتِرُ قَالَتْ ‏:‏ لَمْ يَكُنْ يَدَعُ ذَلِكَ ‏.‏ وَلَمْ يَذْكُرْ أَحْمَدُ ‏:‏ وَسِتٍّ وَثَلاَثٍ ‏.‏\hadithno{1362}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abd Allah b. Abi Qais said that he asked 'Aishah:How many rak'ahs would the Messenger of Allah (ﷺ) pray observing the witr ? She said: He used to observe the witr with four and three, six and three, eight and three, and ten and three rak'ahs never observing less than seven or more than thirteen. The narrator Ahmad added in his version: He would not observe the witr with two rak'ahs before the dawn. I asked: With what would he observe the witr ? She said: He would never leave it. The version of Ahmad does not mention the words "six and three (rak'ahs)}}
\hadithdefcmd{abudawud}{1363}{حَدَّثَنَا مُؤَمَّلُ بْنُ هِشَامٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ مَنْصُورِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي إِسْحَاقَ الْهَمْدَانِيِّ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، ‏:‏ أَنَّهُ دَخَلَ عَلَى عَائِشَةَ فَسَأَلَهَا عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم بِاللَّيْلِ ‏.‏ فَقَالَتْ ‏:‏ كَانَ يُصَلِّي ثَلاَثَ عَشْرَةَ رَكْعَةً مِنَ اللَّيْلِ، ثُمَّ إِنَّهُ صَلَّى إِحْدَى عَشْرَةَ رَكْعَةً، وَتَرَكَ رَكْعَتَيْنِ ثُمَّ قُبِضَ صلى الله عليه وسلم حِينَ قُبِضَ وَهُوَ يُصَلِّي مِنَ اللَّيْلِ تِسْعَ رَكَعَاتٍ، وَكَانَ آخِرُ صَلاَتِهِ مِنَ اللَّيْلِ الْوِتْرَ ‏.‏\hadithno{1363}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Al-Aswad ibn Yazid said that he entered upon Aisha and asked her about the prayer of the Messenger of Allah (ﷺ) during the night. She said: He used to pray thirteen rak'ahs during the night. Then he began to pray eleven rak'ahs and left two rak'ahs. When he died, he would pray nine rak'ahs during the night. His last prayer during the night was witr}}
\hadithdefcmd{abudawud}{1364}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، عَنْ خَالِدِ بْنِ يَزِيدَ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ مَخْرَمَةَ بْنِ سُلَيْمَانَ، أَنَّ كُرَيْبًا، مَوْلَى ابْنِ عَبَّاسٍ أَخْبَرَهُ أَنَّهُ، قَالَ ‏:‏ سَأَلْتُ ابْنَ عَبَّاسٍ كَيْفَ كَانَتْ صَلاَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم بِاللَّيْلِ قَالَ ‏:‏ بِتُّ عِنْدَهُ لَيْلَةً وَهُوَ عِنْدَ مَيْمُونَةَ، فَنَامَ حَتَّى إِذَا ذَهَبَ ثُلُثُ اللَّيْلِ أَوْ نِصْفُهُ اسْتَيْقَظَ فَقَامَ إِلَى شَنٍّ فِيهِ مَاءٌ فَتَوَضَّأَ وَتَوَضَّأْتُ مَعَهُ، ثُمَّ قَامَ فَقُمْتُ إِلَى جَنْبِهِ عَلَى يَسَارِهِ فَجَعَلَنِي عَلَى يَمِينِهِ، ثُمَّ وَضَعَ يَدَهُ عَلَى رَأْسِي كَأَنَّهُ يَمَسُّ أُذُنِي كَأَنَّهُ يُوقِظُنِي فَصَلَّى رَكْعَتَيْنِ خَفِيفَتَيْنِ، قُلْتُ ‏:‏ فَقَرَأَ فِيهِمَا بِأُمِّ الْقُرْآنِ فِي كُلِّ رَكْعَةٍ ثُمَّ سَلَّمَ ثُمَّ صَلَّى حَتَّى صَلَّى إِحْدَى عَشْرَةَ رَكْعَةً بِالْوِتْرِ، ثُمَّ نَامَ فَأَتَاهُ بِلاَلٌ فَقَالَ ‏:‏ الصَّلاَةُ يَا رَسُولَ اللَّهِ ‏.‏ فَقَامَ فَرَكَعَ رَكْعَتَيْنِ، ثُمَّ صَلَّى لِلنَّاسِ ‏.‏\hadithno{1364}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (992) Sahih Muslim (763)}\hadithtrans{The client of Ibn 'Abbas said that he asked him:How would the Messenger of Allah (ﷺ) pray during the night ? He replied: I spent a night with him when he was with Maimunah. He slept and awoke when half the night or one-third of it had passed. He stood up and went to a leather bad containing water. He performed ablution and I also performed ablution with him. He then stood up and I also stood at his left side. He made me stand at his right side. He then put his hand upon my head, as he was touching my ear and awakening me. He then prayed two light rak'ahs and recited Surah al-Fatihah in each of them, and uttered the salutation. He then prayed eleven rak'ahs observing the witr and slept. Then Bilal came to him and said: Prayer, Messenger of Allah. He got up and prayed two rak'ahs, and then led the people in the prayer}}
\hadithdefcmd{abudawud}{1365}{حَدَّثَنَا نُوحُ بْنُ حَبِيبٍ، وَيَحْيَى بْنُ مُوسَى، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ عِكْرِمَةَ بْنِ خَالِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏:‏ بِتُّ عِنْدَ خَالَتِي مَيْمُونَةَ فَقَامَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي مِنَ اللَّيْلِ فَصَلَّى ثَلاَثَ عَشْرَةَ رَكْعَةً مِنْهَا رَكْعَتَا الْفَجْرِ، حَزَرْتُ قِيَامَهُ فِي كُلِّ رَكْعَةٍ بِقَدْرِ ‏\{‏ يَا أَيُّهَا الْمُزَّمِّلُ ‏\}‏ لَمْ يَقُلْ نُوحٌ ‏:‏ مِنْهَا رَكْعَتَا الْفَجْرِ ‏.‏\hadithno{1365}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: I spent a night with my maternal aunt Maymunah. The Prophet (ﷺ) got up to pray at night. He prayed thirteen rak'ahs including two rak'ahs of the dawn prayer. I guessed that he stood in every rak'ah as long as one could recite Surah al-Muzzammil}}
\hadithdefcmd{abudawud}{1366}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِيهِ، أَنَّ عَبْدَ اللَّهِ بْنَ قَيْسِ بْنِ مَخْرَمَةَ، أَخْبَرَهُ عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّهُ - قَالَ - لأَرْمُقَنَّ صَلاَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم اللَّيْلَةَ، قَالَ ‏:‏ فَتَوَسَّدْتُ عَتَبَتَهُ أَوْ فُسْطَاطَهُ، فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم رَكْعَتَيْنِ خَفِيفَتَيْنِ، ثُمَّ صَلَّى رَكْعَتَيْنِ طَوِيلَتَيْنِ طَوِيلَتَيْنِ طَوِيلَتَيْنِ، ثُمَّ صَلَّى رَكْعَتَيْنِ وَهُمَا دُونَ اللَّتَيْنِ قَبْلَهُمَا، ثُمَّ صَلَّى رَكْعَتَيْنِ دُونَ اللَّتَيْنِ قَبْلَهُمَا، ثُمَّ صَلَّى رَكْعَتَيْنِ دُونَ اللَّتَيْنِ قَبْلَهُمَا، ثُمَّ صَلَّى رَكْعَتَيْنِ دُونَ اللَّتَيْنِ قَبْلَهُمَا، ثُمَّ أَوْتَرَ، فَذَلِكَ ثَلاَثَ عَشْرَةَ رَكْعَةً ‏.‏\hadithno{1366}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (765)}\hadithtrans{Khalid al-Juhani said:I shall watch the prayer of the Messenger of Allah (ﷺ) at night. I slept at the threshold of his door or of his tent. The Messenger of Allah (ﷺ) prayed two light rak'ahs, and then prayed two long, long, long rak'ahs. He then prayed two rak'ahs that were not so long as the two rak'ahs before them ; he then prayed two rak'ahs that were less in duration, than the rak'ahs before them; again he prayed two rak'ahs that were less in length then the preceding rak'ahs; he then prayed two rak'ahs that were less in length than the previous rak'ahs. This made altogether thirteen rak'ahs}}
\hadithdefcmd{abudawud}{1367}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ مَخْرَمَةَ بْنِ سُلَيْمَانَ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، أَخْبَرَهُ ‏:‏ أَنَّهُ، بَاتَ عِنْدَ مَيْمُونَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم وَهِيَ خَالَتُهُ - قَالَ - فَاضْطَجَعْتُ فِي عَرْضِ الْوِسَادَةِ، وَاضْطَجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَهْلُهُ فِي طُولِهَا، فَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا انْتَصَفَ اللَّيْلُ - أَوْ قَبْلَهُ بِقَلِيلٍ، أَوْ بَعْدَهُ بِقَلِيلٍ - اسْتَيْقَظَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَجَلَسَ يَمْسَحُ النَّوْمَ عَنْ وَجْهِهِ بِيَدِهِ، ثُمَّ قَرَأَ الْعَشْرَ الآيَاتِ الْخَوَاتِمَ مِنْ سُورَةِ آلِ عِمْرَانَ، ثُمَّ قَامَ إِلَى شَنٍّ مُعَلَّقَةٍ فَتَوَضَّأَ مِنْهَا فَأَحْسَنَ وُضُوءَهُ، ثُمَّ قَامَ يُصَلِّي، قَالَ عَبْدُ اللَّهِ ‏:‏ فَقُمْتُ فَصَنَعْتُ مِثْلَ مَا صَنَعَ، ثُمَّ ذَهَبْتُ فَقُمْتُ إِلَى جَنْبِهِ، فَوَضَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ الْيُمْنَى عَلَى رَأْسِي فَأَخَذَ بِأُذُنِي يَفْتِلُهَا، فَصَلَّى رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، قَالَ الْقَعْنَبِيُّ ‏:‏ سِتَّ مَرَّاتٍ، ثُمَّ أَوْتَرَ، ثُمَّ اضْطَجَعَ، حَتَّى جَاءَهُ الْمُؤَذِّنُ فَقَامَ فَصَلَّى رَكْعَتَيْنِ خَفِيفَتَيْنِ، ثُمَّ خَرَجَ فَصَلَّى الصُّبْحَ ‏.‏\hadithno{1367}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (992) Sahih Muslim (763)}\hadithtrans{Narrated 'Abd Allah b. 'Abbas:That he spent a night with Maimunah, wife of the Prophet (ﷺ), who was also his (Ibn 'Abbas's) maternal aunt. I lay towards the width of the pillow and the Messenger of Allah (ﷺ) and his wife slept towards its length. The Messenger of Allah (ﷺ) slept. When half the night passed, or a little before it or a little after it, the Messenger of Allah (ﷺ) awoke and began to rub his face (eyes) to remove the sleep. He then recited ten verses from the last part of Surah 'Al-Imran. Hen then came to a bag of water that was hanging. He performed ablution from it and performed his ablution well. He then stood up and prayed. I also got up and did as he did. I then went and stood at his side. The Messenger of Allah (ﷺ) placed his right hand upon my head and took me by my ear twisting it. He then prayed two rak'ahs, then two rak'ahs, then two rak'ahs, then two rak'ahs, then two rak'ahs, then two rak'ahs. The narrator al-Qa'nabi said: Six times. He observed the witr prayer, and then slept until the mu'adhdhin came. He got up and prayed two light rak'ahs and then came out and offered the dawn prayer}}
\hadithdefcmd{abudawud}{1368}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏:‏ ‏ "‏ اكْلَفُوا مِنَ الْعَمَلِ مَا تُطِيقُونَ، فَإِنَّ اللَّهَ لاَ يَمَلُّ حَتَّى تَمَلُّوا، وَإِنَّ أَحَبَّ الْعَمَلِ إِلَى اللَّهِ أَدْوَمُهُ وَإِنْ قَلَّ ‏"‏ ‏.‏ وَكَانَ إِذَا عَمِلَ عَمَلاً أَثْبَتَهُ ‏.‏\hadithno{1368}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5861) Sahih Muslim (782)}\hadithtrans{Narrated 'Aishah:The Messenger of Allah (ﷺ) as saying: Choose such actions as you are capable of performing, for Allah does not grow weary till you do. The acts most pleasing to Allah are those which are done most continuously, even if they amount to little. Whenever he began an action, he would do it continuously}}
\hadithdefcmd{abudawud}{1369}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدٍ، حَدَّثَنَا عَمِّي، حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، ‏:‏ أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ إِلَى عُثْمَانَ بْنِ مَظْعُونٍ فَجَاءَهُ فَقَالَ ‏:‏ ‏"‏ يَا عُثْمَانُ أَرَغِبْتَ عَنْ سُنَّتِي ‏"‏ ‏.‏ قَالَ ‏:‏ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ، وَلَكِنْ سُنَّتَكَ أَطْلُبُ ‏.‏ قَالَ ‏:‏ ‏"‏ فَإِنِّي أَنَامُ وَأُصَلِّي، وَأَصُومُ وَأُفْطِرُ، وَأَنْكِحُ النِّسَاءَ، فَاتَّقِ اللَّهَ يَا عُثْمَانُ، فَإِنَّ لأَهْلِكَ عَلَيْكَ حَقًّا، وَإِنَّ لِضَيْفِكَ عَلَيْكَ حَقًّا، وَإِنَّ لِنَفْسِكَ عَلَيْكَ حَقًّا، فَصُمْ وَأَفْطِرْ، وَصَلِّ وَنَمْ ‏"‏ ‏.‏\hadithno{1369}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Aishah:The Prophet (ﷺ) called 'Uthman b. Maz'un. When he came to him, he said: 'Uthman, did you dislike my practice ? He said: No, by Allah, but I seek your practice. He said: I sleep, I pray, I keep fast, I (sometimes) leave fast, and I marry women. Fear Allah, 'Uthman, your wife has a right on you, your guest has a right on you, your self has a right on you ; you should keep fast and (sometimes) leave fast, and pray and sleep}}
\hadithdefcmd{abudawud}{1370}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، قَالَ ‏:‏ سَأَلْتُ عَائِشَةَ كَيْفَ كَانَ عَمَلُ رَسُولِ اللَّهِ صلى الله عليه وسلم هَلْ كَانَ يَخُصُّ شَيْئًا مِنَ الأَيَّامِ قَالَتْ ‏:‏ لاَ، كَانَ كُلُّ عَمَلِهِ دِيمَةً، وَأَيُّكُمْ يَسْتَطِيعُ مَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَسْتَطِيعُ\hadithno{1370}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6466) Sahih Muslim (783)}\hadithtrans{Alqamah said:'Aishah was asked about the actions of the Messenger of Allah (ﷺ). Did he perform some actions exclusively on some particular days ? She said: No, he performed his actions regularly. Which of you has the strength as much as the Messenger of Allah (ﷺ) had ?}}
